@@ -5,9 +5,9 @@
 #       extension: .py
 #       format_name: percent
 #       format_version: '1.3'
-#       jupytext_version: 1.4.2
+#       jupytext_version: 1.11.4
 #   kernelspec:
-#     display_name: Python 3 (ipykernel)
+#     display_name: Python 3
 #     language: python
 #     name: python3
 # ---
@@ -19,8 +19,8 @@
 #
 # .. _ug_1dplots:
 #
-# Plotting 1D data
-# ================
+# 1D plotting
+# ===========
 #
 # ProPlot adds :ref:`several new features <why_plotting>` to matplotlib's
 # plotting commands using the intermediate `~proplot.axes.PlotAxes` subclass.
@@ -37,7 +37,7 @@
 # Standardized arguments
 # ----------------------
 #
-# Input arguments passed to 1D plotting commands are now uniformly
+# Input arguments passed to 1D plot commands are now uniformly
 # standardized. For each command, you can optionally omit the dependent
 # variable coordinates, in which case they are inferred from the data
 # (see :ref:`xarray and pandas integration <ug_1dintegration>`), or pass
@@ -112,17 +112,17 @@ axs[0].axvspan(
 )
 for i, ax in enumerate(axs):
     inbounds = i == 1
-    title = f'Manual limits inbounds={inbounds}'
+    title = f'Manual xlim inbounds={inbounds}'
     title += ' (default)' if inbounds else ''
     ax.format(
         xmax=(None if i == 0 else xmax),
-        title=('Auto x axis limits' if i == 0 else title),
+        title=('Default xlim' if i == 0 else title),
     )
     ax.plot(x, y, cycle=cycle, inbounds=inbounds)
 fig.format(
     xlabel='xlabel',
     ylabel='ylabel',
-    suptitle='Auto y limits with in-bounds data'
+    suptitle='Default ylim restricted to in-bounds data'
 )
 
 
@@ -148,9 +148,9 @@ fig.format(
 #
 # These features restore some of the convenience you get with the builtin
 # `pandas`_ and `xarray`_ plotting functions. They are also *optional* --
-# installation of pandas and xarray are not required. All of these features
-# can be disabled by setting :rcraw:`autoformat` to ``False`` or by passing
-# ``autoformat=False`` to any plotting command.
+# installation of pandas and xarray are not required to use ProPlot. All of these
+# features can be disabled by setting :rcraw:`autoformat` to ``False`` or by
+# passing ``autoformat=False`` to any plotting command.
 
 # %%
 import xarray as xr
@@ -212,30 +212,30 @@ ax.plot(df, cycle=cycle, lw=3, legend='t', legend_kw={'frame': False})
 # ---------------
 #
 # It is often useful to create on-the-fly `property cycles
-# <https://matplotlib.org/tutorials/intermediate/color_cycle.html#sphx-glr-tutorials-intermediate-color-cycle-py>`__
+# <https://matplotlib.org/stable/tutorials/intermediate/color_cycle.html#sphx-glr-tutorials-intermediate-color-cycle-py>`__
 # and use different property cycles for different plot elements. You can create and
 # apply property cycles on-the-fly using the `cycle` and `cycle_kw` keywords, available
-# with most `~proplot.axes.PlotAxes` 1D plotting commands. `cycle` and `cycle_kw` are
+# with most `~proplot.axes.PlotAxes` 1D plot commands. `cycle` and `cycle_kw` are
 # passed to the `~proplot.constructor.Cycle` :ref:`constructor function
 # <why_constructor>`, and the resulting property cycle is used for the plot. You
 # can specify `cycle` once with 2D input data (in which case each column is
 # plotted in succession according to the property cycle) or call a plotting
-# command multiple times with the same `cycle` argument each time (the property
+# command multiple times with the same `cycle` argument (the property
 # cycle is not reset). You can also disable property cycling with
 # ``cycle=False``, ``cycle='none'``, or ``cycle=()`` and re-enable the default
 # property cycle with ``cycle=True``. For more information on property cycling,
 # see the :ref:`color cycles section <ug_cycles>` and `this matplotlib tutorial
-# <https://matplotlib.org/tutorials/intermediate/color_cycle.html#sphx-glr-tutorials-intermediate-color-cycle-py>`__.
+# <https://matplotlib.org/stable/tutorials/intermediate/color_cycle.html#sphx-glr-tutorials-intermediate-color-cycle-py>`__.
 
 # %%
 import proplot as pplt
 import numpy as np
 
 # Sample data
-M, N = 50, 4
+M, N = 50, 5
 state = np.random.RandomState(51423)
-data1 = (state.rand(M, N) - 0.5).cumsum(axis=0)
-data2 = (state.rand(M, N) - 0.5).cumsum(axis=0) * 1.5
+data1 = (state.rand(M, N) - 0.48).cumsum(axis=1).cumsum(axis=0)
+data2 = (state.rand(M, N) - 0.48).cumsum(axis=1).cumsum(axis=0) * 1.5
 data1 += state.rand(M, N)
 data2 += state.rand(M, N)
 
@@ -243,21 +243,23 @@ with pplt.rc.context({'lines.linewidth': 3}):
     # Use property cycle for columns of 2D input data
     fig = pplt.figure(share=False)
     ax = fig.subplot(121)
-    ax.format(title='Grayscale cycle')
+    ax.format(title='Single plot call')
     ax.plot(
-        data1 * data2,
+        2 * data1 + data2,
         cycle='black',  # cycle from monochromatic colormap
         cycle_kw={'ls': ('-', '--', '-.', ':')}
     )
 
     # Use property cycle with successive plot() calls
     ax = fig.subplot(122)
-    ax.format(title='Colorful cycle')
+    ax.format(title='Multiple plot calls')
     for i in range(data1.shape[1]):
         ax.plot(data1[:, i], cycle='Reds', cycle_kw={'N': N, 'left': 0.3})
     for i in range(data1.shape[1]):
         ax.plot(data2[:, i], cycle='Blues', cycle_kw={'N': N, 'left': 0.3})
-    fig.format(xlabel='xlabel', ylabel='ylabel', suptitle='Local property cycles demo')
+    fig.format(
+        xlabel='xlabel', ylabel='ylabel', suptitle='On-the-fly property cycles'
+    )
 
 
 # %% [raw] raw_mimetype="text/restructuredtext"
@@ -269,8 +271,8 @@ with pplt.rc.context({'lines.linewidth': 3}):
 # Line plots can be drawn with `~proplot.axes.PlotAxes.plot` or
 # `~proplot.axes.PlotAxes.plotx` (or their aliases, `~proplot.axes.PlotAxes.line`
 # or `~proplot.axes.PlotAxes.linex`). For the ``x`` commands, positional
-# arguments are interpreted as *x* coordinates or (*y*, *x*) pairs. This is
-# analogous to `~proplot.axes.PlotAxes.barh` and `~proplot.axes.PlotAxes.areax`.
+# arguments are interpreted as *x* coordinates or (*y*, *x*) pairs. This is analogous
+# to `~proplot.axes.PlotAxes.barh` and `~proplot.axes.PlotAxes.fill_betweenx`.
 # Also, the default *x* bounds for lines drawn with `~proplot.axes.PlotAxes.plot`
 # and *y* bounds for lines drawn with `~proplot.axes.PlotAxes.plotx` are now
 # "sticky", i.e. there is no padding between the lines and axes edges by default.
@@ -397,345 +399,6 @@ obj = ax.scatter(
 fig.format(suptitle='Scatter plot demo', xlabel='xlabel', ylabel='ylabel')
 
 
-# %% [raw] raw_mimetype="text/restructuredtext"
-# .. _ug_bar:
-#
-# Bar plots and area plots
-# ------------------------
-#
-# The `~proplot.axes.PlotAxes.bar` and `~proplot.axes.PlotAxes.barh` commands
-# apply default *x* or *y* coordinates if you failed to provide them explicitly
-# and can *group* or *stack* columns of data if you pass 2D arrays instead of
-# 1D arrays -- just like `pandas`_. Similarly, `~proplot.axes.PlotAxes.fill_between`
-# and `~proplot.axes.PlotAxes.fill_betweenx` also apply default *x* or *y* coordinates
-# if you failed to provide them explicitly, and can *stack* or *overlay* columns of
-# data by passing 2D arrays instead of 1D arrays. You can also use the shorthands
-# `~proplot.axes.PlotAxes.area` and `~proplot.axes.PlotAxes.areax` instead of
-# ``fill_between``.
-#
-# For both bar and area plots, you can have different colors for "negative" and
-# "positive" regions using ``negpos=True``, ``negcolor=color``, and ``poscolor=color``
-# (the default colors are :rc:`negcolor` and :rc:`poscolor`). Also, the default *x*
-# bounds for shading drawn with `~proplot.axes.PlotAxes.area` and *y* bounds for
-# shading drawn with `~proplot.axes.PlotAxes.areax` is now "sticky", i.e. there
-# is no padding between the shading and axes edges by default.
-
-# %%
-import proplot as pplt
-import numpy as np
-import pandas as pd
-
-# Sample data
-state = np.random.RandomState(51423)
-data = state.rand(5, 5).cumsum(axis=0).cumsum(axis=1)[:, ::-1]
-data = pd.DataFrame(
-    data, columns=pd.Index(np.arange(1, 6), name='column'),
-    index=pd.Index(['a', 'b', 'c', 'd', 'e'], name='row idx')
-)
-
-# Figure
-pplt.rc.abc = 'a.'
-pplt.rc.titleloc = 'l'
-gs = pplt.GridSpec(nrows=2, hratios=(3, 2))
-fig = pplt.figure(refaspect=2, refwidth=4.8, share=False)
-
-# Side-by-side bars
-ax = fig.subplot(gs[0])
-obj = ax.bar(
-    data, cycle='Reds', edgecolor='red9', colorbar='ul', colorbar_kw={'frameon': False}
-)
-ax.format(xlocator=1, xminorlocator=0.5, ytickminor=False, title='Side-by-side')
-
-# Stacked bars
-ax = fig.subplot(gs[1])
-obj = ax.barh(
-    data.iloc[::-1, :], cycle='Blues', edgecolor='blue9', legend='ur', stack=True,
-)
-ax.format(title='Stacked')
-fig.format(grid=False, suptitle='Bar plot demo')
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Sample data
-state = np.random.RandomState(51423)
-data = state.rand(5, 3).cumsum(axis=0)
-cycle = ('gray3', 'gray5', 'gray7')
-
-# Figure
-fig = pplt.figure(refwidth=2.3, share=False)
-
-# Overlaid area patches
-ax = fig.subplot(121)
-ax.area(
-    np.arange(5), data, data + state.rand(5)[:, None], cycle=cycle, alpha=0.7,
-    legend='uc', legend_kw={'center': True, 'ncols': 2, 'labels': ['z', 'y', 'qqqq']},
-)
-ax.format(title='Fill between columns')
-
-# Stacked area patches
-ax = fig.subplot(122)
-ax.area(
-    np.arange(5), data, stack=True, cycle=cycle, alpha=0.8,
-    legend='ul', legend_kw={'center': True, 'ncols': 2, 'labels': ['z', 'y', 'qqqq']},
-)
-ax.format(title='Stack between columns')
-fig.format(grid=False, xlabel='xlabel', ylabel='ylabel', suptitle='Area plot demo')
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Sample data
-state = np.random.RandomState(51423)
-data = 4 * (state.rand(40) - 0.5)
-
-# Figure
-fig, axs = pplt.subplots(nrows=2, refaspect=2, figwidth=5)
-axs.format(
-    xmargin=0, xlabel='xlabel', ylabel='ylabel', grid=True,
-    suptitle='Positive and negative colors demo',
-)
-for ax in axs:
-    ax.axhline(0, color='k', linewidth=1)  # zero line
-
-# Bar plot
-ax = axs[0]
-ax.bar(data, width=1, negpos=True)
-ax.format(title='Bar plot')
-
-# Area plot
-ax = axs[1]
-ax.area(data, negpos=True, lw=0.5, edgecolor='k')
-ax.format(title='Area plot')
-
-# Reset title styles changed above
-pplt.rc.reset()
-
-
-# %% [raw] raw_mimetype="text/restructuredtext"
-# .. _ug_errorbars:
-#
-# Shading and error bars
-# ----------------------
-#
-# Error bars and error shading can be quickly added on-the-fly to
-# `~proplot.axes.PlotAxes.line`, `~proplot.axes.PlotAxes.linex`
-# (equivalently, `~proplot.axes.PlotAxes.plot`,
-# `~proplot.axes.PlotAxes.plotx`), `~proplot.axes.PlotAxes.scatter`,
-# `~proplot.axes.PlotAxes.scatterx`, `~proplot.axes.PlotAxes.bar`, and
-# `~proplot.axes.PlotAxes.barh` plots using any of several keyword arguments.
-#
-# If you pass 2D arrays to these commands with ``mean=True``, ``means=True``,
-# ``median=True``, or ``medians=True``, the means or medians of each column are
-# drawn as lines, points, or bars, while *error bars* or *error shading*
-# indicates the spread of the distribution in each column. Invalid data is
-# ignored. You can also specify the error bounds *manually* with the `bardata`,
-# `boxdata`, `shadedata`, and `fadedata` keywords. These commands can draw and
-# style thin error bars (the ``bar`` keywords), thick "boxes" overlaid on top of
-# these bars (the ``box`` keywords; think of them as miniature boxplots), a
-# transparent primary shading region (the ``shade`` keywords), and a more
-# transparent secondary shading region (the ``fade`` keywords). See the documentation
-# on the plotting commands for details.
-
-
-# %%
-import numpy as np
-import pandas as pd
-
-# Sample data
-# Each column represents a distribution
-state = np.random.RandomState(51423)
-data = state.rand(20, 8).cumsum(axis=0).cumsum(axis=1)[:, ::-1]
-data = data + 20 * state.normal(size=(20, 8)) + 30
-data = pd.DataFrame(data, columns=np.arange(0, 16, 2))
-data.columns.name = 'column number'
-data.name = 'variable'
-
-# Calculate error data
-# Passed to 'errdata' in the 3rd subplot example
-means = data.mean(axis=0)
-means.name = data.name  # copy name for formatting
-fadedata = np.percentile(data, (5, 95), axis=0)  # light shading
-shadedata = np.percentile(data, (25, 75), axis=0)  # dark shading
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Loop through "vertical" and "horizontal" versions
-varray = [[1], [2], [3]]
-harray = [[1, 1], [2, 3], [2, 3]]
-for orientation, array in zip(('horizontal', 'vertical'), (harray, varray)):
-    # Figure
-    fig = pplt.figure(refwidth=4, refaspect=1.5, share=False)
-    axs = fig.subplots(array, hratios=(2, 1, 1))
-    axs.format(abc='A.', suptitle=f'Indicating {orientation} error bounds')
-
-    # Medians and percentile ranges
-    ax = axs[0]
-    kw = dict(
-        color='light red', legend=True,
-        median=True, barpctile=90, boxpctile=True,
-        # median=True, barpctile=(5, 95), boxpctile=(25, 75)  # equivalent
-    )
-    if orientation == 'horizontal':
-        ax.barh(data, **kw)
-    else:
-        ax.bar(data, **kw)
-    ax.format(title='Bar plot')
-
-    # Means and standard deviation range
-    ax = axs[1]
-    kw = dict(
-        color='denim', marker='x', markersize=8**2, linewidth=0.8,
-        label='mean', shadelabel=True,
-        mean=True, shadestd=1,
-        # mean=True, shadestd=(-1, 1)  # equivalent
-    )
-    if orientation == 'horizontal':
-        ax.scatterx(data, legend='b', legend_kw={'ncol': 1}, **kw)
-    else:
-        ax.scatter(data, legend='ll', **kw)
-    ax.format(title='Marker plot')
-
-    # User-defined error bars
-    ax = axs[2]
-    kw = dict(
-        shadedata=shadedata, fadedata=fadedata,
-        label='mean', shadelabel='50% CI', fadelabel='90% CI',
-        color='ocean blue', barzorder=0, boxmarker=False,
-    )
-    if orientation == 'horizontal':
-        ax.linex(means, legend='b', legend_kw={'ncol': 1}, **kw)
-    else:
-        ax.line(means, legend='ll', **kw)
-    ax.format(title='Line plot')
-
-
-# %% [raw] raw_mimetype="text/restructuredtext" tags=[]
-# .. _ug_hist:
-#
-# Histogram plots
-# ---------------
-#
-# Vertical and horizontal histograms can be drawn with
-# `~proplot.axes.PlotAxes.hist` and `~proplot.axes.PlotAxes.histh`.
-# As with the other plotting commands, multiple histograms can be
-# drawn by passing 2D arrays instead of 1D arrays, and the color
-# cycle used to color histograms can be changed on-the-fly using
-# the `cycle` and `cycle_kw` keywords. Likewise, 2D histograms can
-# be drawn with the `~proplot.axes.PlotAxes.hist2d`
-# `~proplot.axes.PlotAxes.hexbin` commands, and their colormaps can
-# be changed on-the-fly with the `cmap` and `cmap_kw` keywords (see
-# the :ref:`2d plotting section <ug_apply_cmap>`). Marginal distributions
-# for the 2D histograms can be added using :ref:`panel axes <ug_panels>`.
-# In the future, ProPlot may include options for drawing "smooth"
-# kernel density estimations with these commands.
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Sample data
-M, N = 300, 3
-state = np.random.RandomState(51423)
-x = state.normal(size=(M, N)) + state.rand(M)[:, None] * np.arange(N) + 2 * np.arange(N)
-
-# Sample overlayed histograms
-fig, ax = pplt.subplots(refwidth=4, refaspect=(3, 2))
-ax.format(suptitle='Overlaid histograms', xlabel='distribution', ylabel='count')
-res = ax.hist(
-    x, pplt.arange(-3, 8, 0.2), alpha=0.7,
-    cycle=('indigo9', 'gray3', 'red9'), labels=list('abc'), legend='ul',
-)
-
-# %%
-import proplot as pplt
-import numpy as np
-
-# Sample data
-N = 500
-state = np.random.RandomState(51423)
-x = state.normal(size=(N,))
-y = state.normal(size=(N,))
-bins = pplt.arange(-3, 3, 0.25)
-
-# Histogram with marginal distributions
-fig, axs = pplt.subplots(ncols=2, refwidth=2.3)
-axs.format(
-    abc='A.', abcloc='l', titleabove=True,
-    ylabel='y axis', suptitle='Histograms with marginal distributions'
-)
-colors = ('indigo9', 'red9')
-titles = ('Group 1', 'Group 2')
-for ax, which, color, title in zip(axs, 'lr', colors, titles):
-    ax.hist2d(
-        x, y, bins, vmin=0, vmax=10, levels=50,
-        cmap=color, colorbar='b', colorbar_kw={'label': 'count'}
-    )
-    color = pplt.scale_luminance(color, 1.5)  # histogram colors
-    px = ax.panel(which, space=0)
-    px.hist(y, bins, lw=0, color=color, vert=False)  # or orientation='horizontal'
-    px.format(grid=False, xlocator=[], xreverse=(which == 'l'))
-    px = ax.panel('t', space=0)
-    px.hist(x, bins, lw=0, color=color)
-    px.format(grid=False, ylocator=[], title=title, titleloc='l')
-
-# %% [raw] raw_mimetype="text/restructuredtext"
-# .. _ug_boxplots:
-#
-# Box plots and violin plots
-# --------------------------
-#
-# Vertical and horizontal box and violin plots can be drawn using
-# `~proplot.axes.PlotAxes.boxplot`, `~proplot.axes.PlotAxes.violinplot`,
-# `~proplot.axes.PlotAxes.boxploth`, and `~proplot.axes.PlotAxes.violinploth` (or
-# their new shorthands, `~proplot.axes.PlotAxes.box`, `~proplot.axes.PlotAxes.violin`,
-# `~proplot.axes.PlotAxes.boxh`, and `~proplot.axes.PlotAxes.violinh`). The
-# ProPlot versions employ aesthetically pleasing defaults and permit flexible
-# configuration using keywords like `color`, `barcolor`, and `fillcolor`.
-# They also automatically apply axis labels based on the `~pandas.DataFrame`
-# or `~xarray.DataArray` column labels.
-
-# %%
-import proplot as pplt
-import numpy as np
-import pandas as pd
-
-# Sample data
-N = 500
-state = np.random.RandomState(51423)
-data1 = state.normal(size=(N, 5)) + 2 * (state.rand(N, 5) - 0.5) * np.arange(5)
-data1 = pd.DataFrame(data1, columns=pd.Index(list('abcde'), name='label'))
-data2 = state.rand(100, 7)
-data2 = pd.DataFrame(data2, columns=pd.Index(list('abcdefg'), name='label'))
-
-# Figure
-fig, axs = pplt.subplots([[1, 1, 2, 2], [0, 3, 3, 0]], span=False)
-axs.format(
-    abc='A.', titleloc='l', grid=False,
-    suptitle='Boxes and violins demo'
-)
-
-# Box plots
-ax = axs[0]
-obj1 = ax.boxplot(data1, means=True, marker='x', meancolor='r', fillcolor='gray4')
-ax.format(title='Box plots')
-
-# Violin plots
-ax = axs[1]
-obj2 = ax.violinplot(data1, fillcolor='gray6', means=True, points=100)
-ax.format(title='Violin plots')
-
-# Boxes with different colors
-ax = axs[2]
-colors = pplt.get_colors('pastel2')  # list of colors from the cycle
-ax.boxplot(data2, fillcolor=colors, orientation='horizontal')
-ax.format(title='Multiple colors', ymargin=0.15)
-
-
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_parametric:
 #
@@ -792,3 +455,148 @@ ax.format(
     xlabel='cosine angle', ylabel='sine angle'
 )
 ax.colorbar(m, loc='b', maxn=10, label='parametric coordinate')
+
+
+# %% [raw] raw_mimetype="text/restructuredtext"
+# .. _ug_bar:
+#
+# Bar plots and area plots
+# ------------------------
+#
+# The `~proplot.axes.PlotAxes.bar` and `~proplot.axes.PlotAxes.barh` commands
+# apply default *x* or *y* coordinates if you failed to provide them explicitly
+# and can *group* or *stack* successive columns of data if you pass 2D arrays instead
+# of 1D arrays -- just like `pandas`_. The widths of bars are expressed in step
+# size-relative units by default, but matplotlib's behavior can be restored by
+# passing ``absolute_width=True``. When bars are grouped, their widths are
+# positions are adjusted according to the number of bars in the group.
+#
+# The `~proplot.axes.PlotAxes.fill_between` and `~proplot.axes.PlotAxes.fill_betweenx`
+# have the new shorthands `~proplot.axes.PlotAxes.area`
+# and `~proplot.axes.PlotAxes.areax`. Similar to `~proplot.axes.PlotAxes.bar` and
+# `~proplot.axes.PlotAxes.barh`, they apply default *x* coordinates if you failed
+# to provide them explicitly, and can *overlay* or *stack* successive columns of
+# data if you pass 2D arrays instead of 1D arrays -- just like `pandas`_. Also, the
+# default *x* bounds for shading drawn with `~proplot.axes.PlotAxes.area` and *y*
+# bounds for shading drawn with `~proplot.axes.PlotAxes.areax` is now "sticky",
+# i.e. there is no padding between the shading and axes edges by default.
+
+# %%
+import proplot as pplt
+import numpy as np
+import pandas as pd
+
+# Sample data
+state = np.random.RandomState(51423)
+data = state.rand(5, 5).cumsum(axis=0).cumsum(axis=1)[:, ::-1]
+data = pd.DataFrame(
+    data, columns=pd.Index(np.arange(1, 6), name='column'),
+    index=pd.Index(['a', 'b', 'c', 'd', 'e'], name='row idx')
+)
+
+# Figure
+pplt.rc.abc = 'a.'
+pplt.rc.titleloc = 'l'
+gs = pplt.GridSpec(nrows=2, hratios=(3, 2))
+fig = pplt.figure(refaspect=2, refwidth=4.8, share=False)
+
+# Side-by-side bars
+ax = fig.subplot(gs[0])
+obj = ax.bar(
+    data, cycle='Reds', edgecolor='red9', colorbar='ul', colorbar_kw={'frameon': False}
+)
+ax.format(xlocator=1, xminorlocator=0.5, ytickminor=False, title='Side-by-side')
+
+# Stacked bars
+ax = fig.subplot(gs[1])
+obj = ax.barh(
+    data.iloc[::-1, :], cycle='Blues', edgecolor='blue9', legend='ur', stack=True,
+)
+ax.format(title='Stacked')
+fig.format(grid=False, suptitle='Bar plot demo')
+pplt.rc.reset()
+
+# %%
+import proplot as pplt
+import numpy as np
+
+# Sample data
+state = np.random.RandomState(51423)
+data = state.rand(5, 3).cumsum(axis=0)
+cycle = ('gray3', 'gray5', 'gray7')
+
+# Figure
+pplt.rc.abc = 'a.'
+pplt.rc.titleloc = 'l'
+fig = pplt.figure(refwidth=2.3, share=False)
+
+# Overlaid area patches
+ax = fig.subplot(121)
+ax.area(
+    np.arange(5), data, data + state.rand(5)[:, None], cycle=cycle, alpha=0.7,
+    legend='uc', legend_kw={'center': True, 'ncols': 2, 'labels': ['z', 'y', 'qqqq']},
+)
+ax.format(title='Fill between columns')
+
+# Stacked area patches
+ax = fig.subplot(122)
+ax.area(
+    np.arange(5), data, stack=True, cycle=cycle, alpha=0.8,
+    legend='ul', legend_kw={'center': True, 'ncols': 2, 'labels': ['z', 'y', 'qqqq']},
+)
+ax.format(title='Stack between columns')
+fig.format(grid=False, xlabel='xlabel', ylabel='ylabel', suptitle='Area plot demo')
+pplt.rc.reset()
+
+# %% [raw] raw_mimetype="text/restructuredtext"
+# .. _ug_negpos:
+#
+# Negative and positive colors
+# ----------------------------
+#
+# You can use different colors for "negative" and
+# "positive" data by passing ``negpos=True`` to any of the
+# `~proplot.axes.PlotAxes.fill_between`, `~proplot.axes.PlotAxes.fill_betweenx`
+# (shorthands `~proplot.axes.PlotAxes.area`, `~proplot.axes.PlotAxes.areax`),
+# `~proplot.axes.PlotAxes.vlines`, `~proplot.axes.PlotAxes.hlines`,
+# `~proplot.axes.PlotAxes.bar`, or `~proplot.axes.PlotAxes.barh` plotting commands.
+# The default negative and positive colors are controlled with :rcraw:`negcolor`
+# and :rcraw:`poscolor` but the colors can be modified for particular plots by
+# passing ``negcolor=color`` and ``poscolor=color`` to the plotting commands.
+
+# %%
+import proplot as pplt
+import numpy as np
+
+# Sample data
+state = np.random.RandomState(51423)
+data = 4 * (state.rand(40) - 0.5)
+
+# Figure
+pplt.rc.abc = 'a.'
+pplt.rc.titleloc = 'l'
+fig, axs = pplt.subplots(nrows=3, refaspect=2, figwidth=5)
+axs.format(
+    xmargin=0, xlabel='xlabel', ylabel='ylabel', grid=True,
+    suptitle='Positive and negative colors demo',
+)
+for ax in axs:
+    ax.axhline(0, color='k', linewidth=1)  # zero line
+
+# Line plot
+ax = axs[0]
+ax.vlines(data, linewidth=3, negpos=True)
+ax.format(title='Line plot')
+
+# Bar plot
+ax = axs[1]
+ax.bar(data, width=1, negpos=True, edgecolor='k')
+ax.format(title='Bar plot')
+
+# Area plot
+ax = axs[2]
+ax.area(data, negpos=True, lw=0.5, edgecolor='k')
+ax.format(title='Area plot')
+
+# Reset title styles changed above
+pplt.rc.reset()
