@@ -6,9 +6,9 @@
 #       extension: .py
 #       format_name: percent
 #       format_version: '1.3'
-#       jupytext_version: 1.4.2
+#       jupytext_version: 1.11.4
 #   kernelspec:
-#     display_name: Python 3 (ipykernel)
+#     display_name: Python 3
 #     language: python
 #     name: python3
 # ---
@@ -39,7 +39,7 @@
 # :ref:`subclassed from <ug_cmaps_new>`
 # `matplotlib.colors.LinearSegmentedColormap`.
 #
-# ProPlot :ref:`adds several features <why_colormaps_cyles>` to help you use
+# ProPlot :ref:`adds several features <why_colormaps_cycles>` to help you use
 # colormaps effectively in your figures. This section documents the new registered
 # colormaps, explains how to make and modify colormaps, and shows how to apply them
 # to your plots.
@@ -390,22 +390,23 @@ axs.format(
 )
 
 # Cutting out central colors
-levels = pplt.arange(-10, 10, 2)
-for i, (ax, cut) in enumerate(zip(axs, (None, None, 0.2, -0.1))):
-    levels = pplt.arange(-10, 10, 2)
-    if i == 1 or i == 3:
-        levels = pplt.edges(levels)
-    if i < 2:
-        title = 'Negative-positive cutoff' if i == 0 else 'Neutral-valued center'
-        title = f'{title}\nlen(levels) = {len(levels)}'
+titles = (
+    'Negative-positive cutoff', 'Neutral-valued center',
+    'Sharper cutoff', 'Expanded center'
+)
+for i, (ax, title, cut) in enumerate(zip(axs, titles, (None, None, 0.2, -0.1))):
+    if i % 2 == 0:
+        kw = {'levels': pplt.arange(-10, 10, 2)}  # negative-positive cutoff
     else:
-        title = 'Sharper cutoff' if cut > 0 else 'Expanded center'
-        title = f'{title}\ncut = {cut}'
+        kw = {'values': pplt.arange(-10, 10, 2)}  # dedicated center
+    if cut is not None:
+        fmt = pplt.SimpleFormatter()  # a proper minus sign
+        title = f'{title}\ncut = {fmt(cut)}'
     ax.format(title=title)
     m = ax.contourf(
-        data, cmap='Div', cmap_kw={'cut': cut},
-        extend='both', levels=levels,
+        data, cmap='Div', cmap_kw={'cut': cut}, extend='both',
         colorbar='b', colorbar_kw={'locator': 'null'},
+        **kw  # level edges or centers
     )
 
 # %%
@@ -477,6 +478,6 @@ for ax, gamma in zip(axs, (0.7, 1.0, 1.4)):
 # to the ``cmaps`` subfolder inside `~proplot.config.Configurator.user_folder`
 # and call `~proplot.config.register_cmaps` (or restart your python session). You
 # can also use `~proplot.colors.ContinuousColormap.from_file` or manually pass
-# colormaps or file paths to `~proplot.config.register_cmaps` See
+# continuous colormaps or file paths to `~proplot.config.register_cmaps`. See
 # `~proplot.colors.ContinuousColormap.from_file` for a table of valid
 # data file extensions.
