@@ -56,9 +56,7 @@ release = ''
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
-    # 'matplotlib.sphinxext.plot_directive', # see: https://matplotlib.org/sampledoc/extensions.html  # noqa
-    'IPython.sphinxext.ipython_console_highlighting',
-    'IPython.sphinxext.ipython_directive',  # for ipython highlighting
+    # 'matplotlib.sphinxext.plot_directive', # see: https://matplotlib.org/sampledoc/extensions.html  # noqa: E501
     'sphinx.ext.autodoc',  # include documentation from docstrings
     'sphinx.ext.doctest',  # >>> examples
     'sphinx.ext.extlinks',  # for :pr:, :issue:, :commit:
@@ -71,7 +69,7 @@ extensions = [
     'sphinx.ext.autosummary',  # autosummary directive
     'sphinxext.custom_roles',  # local extension
     'sphinx_copybutton',
-    'sphinx_automodapi.automodapi',  # see: https://github.com/lukelbd/sphinx-automodapi/tree/proplot-mods # noqa
+    'sphinx_automodapi.automodapi',  # see: https://github.com/lukelbd/sphinx-automodapi/tree/proplot-mods  # noqa: E501
     'nbsphinx',
 ]
 
@@ -169,26 +167,24 @@ napoleon_google_docstring = False
 napoleon_include_init_with_doc = False  # move init doc to 'class' doc
 napoleon_preprocess_types = True
 napoleon_type_aliases = {
-    # General terms
-    'sequence': ':term:`sequence`',
-    'iterable': ':term:`iterable`',
+    # Python or inherited terms
+    # NOTE: float, int, and str are automatically included
     'callable': ':py:func:`callable`',
-    'mapping': ':term:`mapping`',
-    'hashable': ':term:`hashable <name>`',
+    'sequence': ':term:`sequence`',
     'dict-like': ':term:`dict-like <mapping>`',
     'path-like': ':term:`path-like <path-like object>`',
-    'file-like': ':term:`file-like <file-like object>`',
-    'bool': ':class:`bool <bool>`',
-    'string': ':class:`string <str>`',
-    'scalar': ':term:`scalar`',
-    'array-like': ':term:`array-like`',
-    # ProPlot terms
-    'locator-like': ':term:`locator-like <locator>`',
-    'formatter-like': ':term:`formatter-like <formatter>`',
-    'scale-like': ':term:`scale-like <formatter>`',
-    'colormap-like': ':term:`colormap-spec <colormap>`',
-    'cycle-like': ':term:`cycle-spec <cycle>`',
-    'color-like': ':py:func:`color-like <matplotlib.colors.is_color_like>`',
+    'array-like': ':term:`array-like <array_like>`',
+    # ProPlot defined terms
+    'unit-spec': ':py:func:`unit-spec <proplot.utils.units>`',
+    'locator-spec': ':py:func:`locator-spec <proplot.constructor.Locator>`',
+    'formatter-spec': ':py:func:`formatter-spec <proplot.constructor.Formatter>`',
+    'scale-spec': ':py:func:`scale-spec <proplot.constructor.Scale>`',
+    'colormap-spec': ':py:func:`colormap-spec <proplot.constructor.Colormap>`',
+    'cycle-spec': ':py:func:`cycle-spec <proplot.constructor.Cycle>`',
+    'norm-spec': ':py:func:`norm-spec <proplot.constructor.Norm>`',
+    'color-spec': ':py:func:`color-spec <matplotlib.colors.is_color_like>`',
+    'channel-spec': ':py:func:`color-spec <matplotlib.colors.is_color_like>`',
+    'artist': ':py:func:`artist <matplotlib.artist.Artist>`',
 }
 
 # Fix duplicate class member documentation from autosummary + numpydoc
