@@ -11,7 +11,7 @@ from .. import scale as pscale
 from .. import ticker as pticker
 from ..config import _parse_format, rc
 from ..internals import ic  # noqa: F401
-from ..internals import _not_none, _snippet_manager, docstring, rcsetup, warnings
+from ..internals import _not_none, docstring, rcsetup, text, warnings
 from . import plot, shared
 
 __all__ = ['CartesianAxes']
@@ -38,18 +38,23 @@ Parameters
 {args} : optional
     Prepended with ``'{x}'`` and passed to `Axes.format`.
 
+Returns
+-------
+CartesianAxes
+    The new axes.
+
 Note
 ----
-This enforces the following settings:
+This enforces the following default settings:
 
-* Places the old *{x}* axis on the {x1} and the new *{x}*
+* Places the old {x} axis on the {x1} and the new {x}
   axis on the {x2}.
 * Makes the old {x2} spine invisible and the new {x1}, {y1},
   and {y2} spines invisible.
-* Adjusts the *{x}* axis tick, tick label, and axis label positions
+* Adjusts the {x} axis tick, tick label, and axis label positions
   according to the visible spine positions.
-* Syncs the old and new *{y}* axis limits and scales, and makes the
-  new *{y}* axis labels invisible.
+* Syncs the old and new {y} axis limits and scales, and makes the
+  new {y} axis labels invisible.
 """
 _shared_x_keys = dict(
     x='x', x1='bottom', x2='top',
@@ -65,29 +70,36 @@ _shared_y_keys = dict(
 )
 
 # Alt docstrings
+# NOTE: Used by SubplotGrid.altx
 _alt_descrip = """
-Return an axes in the same location as this one but whose {x}
-axis is on the {x2}. This is an alias and more intuitive name
-for `~CartesianAxes.twin{y}`, which generates two *{x}* axes
-with a shared ("twin") *{y}* axes.
+Add an axes locked to the same location with a
+distinct {x} axis.
+This is an alias and possibly more intuitive name for
+`~CartesianAxes.twin{y}`, which generates two {x} axes
+with a shared ("twin") {y} axes.
 """
 _alt_docstring = _shared_docstring % {'descrip': _alt_descrip, 'extra': ''}
-_snippet_manager['axes.altx'] = _alt_docstring.format(**_shared_x_keys)
-_snippet_manager['axes.alty'] = _alt_docstring.format(**_shared_y_keys)
+docstring._snippet_manager['axes.altx'] = _alt_docstring.format(**_shared_x_keys)
+docstring._snippet_manager['axes.alty'] = _alt_docstring.format(**_shared_y_keys)
 
 # Twin docstrings
+# NOTE: Used by SubplotGrid.twinx
 _twin_descrip = """
-Return an axes in the same location as this one but whose {x}
-axis is on the {x2}. Mimics `matplotlib.axes.Axes.twin{y}`.
+Add an axes locked to the same location with a
+distinct {x} axis.
+This builds upon `matplotlib.axes.Axes.twin{y}`.
 """
 _twin_docstring = _shared_docstring % {'descrip': _twin_descrip, 'extra': ''}
-_snippet_manager['axes.twinx'] = _twin_docstring.format(**_shared_y_keys)
-_snippet_manager['axes.twiny'] = _twin_docstring.format(**_shared_x_keys)
+docstring._snippet_manager['axes.twinx'] = _twin_docstring.format(**_shared_y_keys)
+docstring._snippet_manager['axes.twiny'] = _twin_docstring.format(**_shared_x_keys)
 
 # Dual docstrings
+# NOTE: Used by SubplotGrid.dualx
 _dual_descrip = """
-Return a secondary *{x}* axis for denoting equivalent *{x}*
-coordinates in *alternate units*.
+Add an axes locked to the same location whose {x} axis denotes
+equivalent coordinates in alternate units.
+This is an alternative to `matplotlib.axes.Axes.secondary_{x}axis` with
+additional convenience features.
 """
 _dual_extra = """
 funcscale : callable, 2-tuple of callables, or scale-spec
@@ -98,9 +110,9 @@ funcscale : callable, 2-tuple of callables, or scale-spec
     any of which will be used to build a `~proplot.scale.FuncScale` and
     applied to the dual axis (see `~proplot.scale.FuncScale` for details).
 """
-_dual_docstring = _shared_docstring % {'descrip': _dual_descrip, 'extra': _dual_extra.strip()}  # noqa: E501
-_snippet_manager['axes.dualx'] = _dual_docstring.format(**_shared_x_keys)
-_snippet_manager['axes.dualy'] = _dual_docstring.format(**_shared_y_keys)
+_dual_docstring = _shared_docstring % {'descrip': _dual_descrip, 'extra': _dual_extra.lstrip()}  # noqa: E501
+docstring._snippet_manager['axes.dualx'] = _dual_docstring.format(**_shared_x_keys)
+docstring._snippet_manager['axes.dualy'] = _dual_docstring.format(**_shared_y_keys)
 
 
 class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
@@ -109,8 +121,8 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
     Adds the `~CartesianAxes.format` method and overrides several existing
     methods.
     """
-    #: The registered projection name.
-    name = 'proplot_cartesian'
+    _name = 'cartesian'
+    _name_aliases = ('cart', 'rect', 'rectilinar')  # include matplotlib name
 
     def __init__(self, *args, **kwargs):
         """
@@ -153,7 +165,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if self._sharex is not None:
             level = 3 if self._panel_sharex_group else self.figure._sharex
             if level > 0:
-                self._transfer_text(axis.label, self._sharex.xaxis.label)
+                text._transfer_text(axis.label, self._sharex.xaxis.label)
                 axis.label.set_visible(False)
             if level > 2:
                 # WARNING: Cannot set NullFormatter because shared axes share the
@@ -164,7 +176,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         if self._sharey is not None:
             level = 3 if self._panel_sharey_group else self.figure._sharey
             if level > 0:
-                self._transfer_text(axis.label, self._sharey.yaxis.label)
+                text._transfer_text(axis.label, self._sharey.yaxis.label)
                 axis.label.set_visible(False)
             if level > 2:
                 axis.set_tick_params(which='both', labelleft=False, labelright=False)
@@ -617,7 +629,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             getattr(self, x + 'axis').set_label_position(labelloc)
 
     @docstring._obfuscate_signature
-    @_snippet_manager
+    @docstring._snippet_manager
     def format(
         self, *,
         aspect=None,
@@ -674,7 +686,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xlabel, ylabel : str, optional
             The x and y axis labels. Applied with `~matplotlib.axes.Axes.set_xlabel`
             and `~matplotlib.axes.Axes.set_ylabel`.
-        xlabelpad, ylabelpad : float or str, optional
+        xlabelpad, ylabelpad : unit-spec, optional
             The padding between the x and y axis bounding box and the
             x and y axis labels. Default is :rc:`label.pad`.
             %(units.pt)s
@@ -693,7 +705,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xreverse, yreverse : bool, optional
             Whether to "reverse" the x and y axis direction. Makes the x and
             y axes ascend left-to-right and top-to-bottom, respectively.
-        xscale, yscale : axis scale spec, optional
+        xscale, yscale : scale-spec, optional
             The x and y axis scales. Passed to the `~proplot.scale.Scale` constructor.
             For example, ``xscale='log'`` applies logarithmic scaling, and
             ``xscale=('cutoff', 100, 2)`` applies a `~proplot.scale.CutoffScale`.
@@ -715,7 +727,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xticklabeldir, yticklabeldir : {'in', 'out'}
             Whether to place x and y axis tick label text inside
             or outside the axes.
-        xticklabelpad, yticklabelpad : float or str, optional
+        xticklabelpad, yticklabelpad : unit-spec, optional
             The padding between the x and y axis ticks and
             tick labels. Default is :rcraw:`tick.labelpad`.
             %(units.pt)s
@@ -725,7 +737,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         xgridminor, ygridminor, gridminor : bool, optional
             Whether to draw minor gridlines for the x and y axis.
             Use `gridminor` to toggle both.
-        xlocator, ylocator : locator spec, optional
+        xlocator, ylocator : locator-spec, optional
             Used to determine the x and y axis tick mark positions. Passed
             to the `~proplot.constructor.Locator` constructor.  Can be float,
             list of float, string, or `matplotlib.ticker.Locator` instance.
@@ -740,7 +752,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             Aliases for `xminorlocator`, `yminorlocator`.
         xminorlocator_kw, yminorlocator_kw
             As for `xlocator_kw`, `ylocator_kw`, but for the minor locator.
-        xformatter, yformatter : formatter spec, optional
+        xformatter, yformatter : formatter-spec, optional
             Used to determine the x and y axis tick label string format.
             Passed to the `~proplot.constructor.Formatter` constructor.
             Can be string, list of strings, or `matplotlib.ticker.Formatter`
@@ -773,11 +785,10 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             Use this if you want whitespace between plotted content
             and the spines, but don't want to explicitly set `xlim` or `ylim`.
         xticklen, yticklen, ticklen : float or str, optional
-            Tick lengths for the x and y axis. Units are interpreted by
-            `~proplot.utils.units`, with "points" as the numeric unit.
-            Default is :rc:`ticklen`. Minor tick lengths are scaled according
-            to :rc:`tick.lenratio`. Use `ticklen` and `ticklenratio` to set
-            both at once.
+            Tick lengths for the x and y axis. Default is :rc:`ticklen`.
+            %(units.pt)s
+            Minor tick lengths are scaled according to :rc:`tick.lenratio`.
+            Use `ticklen` and `ticklenratio` to set both at once.
         xlinewidth, ylinewidth, linewidth : color-spec, optional
             Line width for the x and y axis spines and major ticks.
             Use `linewidth` to set both at once.
@@ -802,6 +813,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         See also
         --------
         proplot.axes.Axes.format
+        proplot.figure.Figure.format
         proplot.config.Configurator.context
 
         Note
@@ -971,7 +983,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
             self.set_aspect(aspect)
         super().format(rc_kw=rc_kw, rc_mode=rc_mode, **kwargs)
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def altx(self, **kwargs):
         """
         %(axes.altx)s
@@ -993,7 +1005,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         # zorder of 4 and make the background transparent.
         minorlocator = self.yaxis.get_minor_locator()
         ax = self._make_twin_axes(
-            sharey=self, number=False, autoshare=False, projection='proplot_cartesian'
+            sharey=self, number=False, autoshare=False, projection='cartesian'
         )
 
         # Child defaults
@@ -1023,7 +1035,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
 
         return ax
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def alty(self, **kwargs):
         """
         %(axes.alty)s
@@ -1031,7 +1043,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         # See altx() comments
         minorlocator = self.xaxis.get_minor_locator()
         ax = self._make_twin_axes(
-            sharex=self, number=False, autoshare=False, projection='proplot_cartesian'
+            sharex=self, number=False, autoshare=False, projection='cartesian'
         )
 
         # Child defaults
@@ -1061,7 +1073,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
 
         return ax
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def dualx(self, funcscale, **kwargs):
         """
         %(axes.dualx)s
@@ -1074,7 +1086,7 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         ax._dualx_scale()
         return ax
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def dualy(self, funcscale, **kwargs):
         """
         %(axes.dualy)s
@@ -1085,14 +1097,14 @@ class CartesianAxes(shared._SharedAxes, plot.PlotAxes):
         ax._dualy_scale()
         return ax
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def twinx(self):
         """
         %(axes.twinx)s
         """
         return self.alty()
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def twiny(self):
         """
         %(axes.twiny)s
