@@ -14,13 +14,7 @@ from .. import constructor
 from .. import crs as pcrs
 from ..config import _parse_format, rc
 from ..internals import ic  # noqa: F401
-from ..internals import (
-    _not_none,
-    _snippet_manager,
-    _version_cartopy,
-    docstring,
-    warnings,
-)
+from ..internals import _not_none, dependencies, docstring, warnings
 from . import plot
 
 try:
@@ -75,8 +69,8 @@ class _GeoAxis(object):
         self._interval = None
 
     def _get_extent(self):
-        # Try to get extent but bail out for projections where this is impossible
-        # So far just transverse Mercator
+        # Try to get extent but bail out for projections where this is
+        # impossible. So far just transverse Mercator
         try:
             return self.axes.get_extent()
         except Exception:
@@ -104,7 +98,7 @@ class _GeoAxis(object):
         # cartopy projection and the user cartopy version. Basemap axes will
         # provide projection==None and so will always be false.
         return (
-            _version_cartopy >= 0.18
+            dependencies._version_cartopy >= 0.18
             and cticker is not None
             and isinstance(projection, (ccrs._RectangularProjection, ccrs.Mercator))
         )
@@ -372,7 +366,7 @@ class GeoAxes(plot.PlotAxes):
         return array
 
     @docstring._obfuscate_signature
-    @_snippet_manager
+    @docstring._snippet_manager
     def format(
         self, *,
         lonlim=None, latlim=None, boundinglat=None,
@@ -417,7 +411,7 @@ class GeoAxes(plot.PlotAxes):
         longridminor, latgridminor : bool, optional
             Whether to draw "minor" longitude and latitude lines.
             Default is :rc:`gridminor`. Use `gridminor` to toggle both.
-        lonlocator, latlocator : locator spec, optional
+        lonlocator, latlocator : locator-spec, optional
             Used to determine the longitude and latitude gridline locations.
             Passed to the `~proplot.constructor.Locator` constructor. Can be
             string, float, list of float, or `matplotlib.ticker.Locator` instance.
@@ -466,7 +460,7 @@ class GeoAxes(plot.PlotAxes):
                `~mpl_toolkits.basemap.Basemap.drawparallels` `labels`
                keyword.
 
-        lonformatter, latformatter : formatter spec, optional
+        lonformatter, latformatter : formatter-spec, optional
             Formatter used to style longitude and latitude gridline labels.
             Passed to the `~proplot.constructor.Formatter` constructor.
             Can be string, list of string, or `matplotlib.ticker.Formatter`
@@ -490,7 +484,7 @@ class GeoAxes(plot.PlotAxes):
             *For cartopy axes only.*
             Whether to rotate longitude and latitude gridline labels.
             Default is :rc:`grid.rotatelabels`.
-        labelpad : float, optional
+        labelpad : unit-spec, optional
             *For cartopy axes only.*
             The padding between the map boundary and longitude and
             latitude gridline labels. Default is :rc:`grid.labelpad`.
@@ -539,12 +533,13 @@ class GeoAxes(plot.PlotAxes):
         # drawing gridlines before basemap map boundary will call set_axes_limits()
         # which initializes a boundary hidden from external access. So we must call
         # it here. Must do this between matplotlib.Axes.__init__() and Axes.format().
-        if (
-            self.name == 'proplot_basemap'
-            and self.projection.projection in self._proj_non_rectangular
-            and self._map_boundary is None
-        ):
-            self._map_boundary = self.projection.drawmapboundary(ax=self)
+        if self._name == 'basemap' and self._map_boundary is None:
+            if self.projection.projection in self._proj_non_rectangular:
+                patch = self.projection.drawmapboundary(ax=self)
+                self._map_boundary = patch
+            else:
+                self.projection.set_axes_limits(self)  # initialize aspect ratio
+                self._map_boundary = object()  # sentinel
 
         # Initiate context block
         rc_kw, rc_mode, kwargs = _parse_format(**kwargs)
@@ -658,8 +653,8 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
     """
     Axes subclass for plotting cartopy projections.
     """
-    #: The registered projection name.
-    name = 'proplot_cartopy'
+    _name = 'cartopy'
+    _name_aliases = ('geo', 'geographic')  # default 'geographic' axes
     _proj_class = Projection
     _proj_north = (
         pcrs.NorthPolarStereo,
@@ -689,7 +684,9 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         # NOTE: Initial extent is configured in _update_extent
         import cartopy  # noqa: F401 verify package is available
         if not isinstance(map_projection, ccrs.Projection):
-            raise ValueError('CartopyAxes requires map_projection=cartopy.crs.Projection.')  # noqa: E501
+            raise ValueError(
+                'Cartopy axes require map_projection=cartopy.crs.Projection.'
+            )
         latmax = 90
         boundinglat = None
         polar = isinstance(map_projection, self._proj_polar)
@@ -760,7 +757,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         # the time between v0.17 and v0.18 is any indication.
         def _draw_gridliner(self, *args, **kwargs):
             result = type(self)._draw_gridliner(self, *args, **kwargs)
-            if _version_cartopy >= 0.18:
+            if dependencies._version_cartopy >= 0.18:
                 lon_lim, _ = self._axes_domain()
                 if abs(np.diff(lon_lim)) == abs(np.diff(self.crs.x_limits)):
                     for collection in self.xline_artists:
@@ -773,7 +770,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         # to values between lon_0 - 180 and lon_0 + 180.
         def _axes_domain(self, *args, **kwargs):
             x_range, y_range = type(self)._axes_domain(self, *args, **kwargs)
-            if _version_cartopy < 0.18:
+            if dependencies._version_cartopy < 0.18:
                 lon_0 = self.axes.projection.proj4_params.get('lon_0', 0)
                 x_range = np.asarray(x_range) + lon_0
             return x_range, y_range
@@ -787,7 +784,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         # 4. lonlines go from lon_0 - 180 to lon_0 + 180 monotonic, but prevents
         #    labels from being drawn outside of range (-180, 180)
         def _add_gridline_label(self, value, axis, upper_end):
-            if _version_cartopy < 0.18:
+            if dependencies._version_cartopy < 0.18:
                 if axis == 'x':
                     value = (value + 180) % 360 - 180
             return type(self)._add_gridline_label(self, value, axis, upper_end)
@@ -804,7 +801,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         """
         Toggle gridliner labels across different cartopy versions.
         """
-        if _version_cartopy >= 0.18:  # cartopy >= 0.18
+        if dependencies._version_cartopy >= 0.18:  # cartopy >= 0.18
             left_labels = 'left_labels'
             right_labels = 'right_labels'
             bottom_labels = 'bottom_labels'
@@ -886,7 +883,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         kw_face, kw_edge = self._get_background_props(context=context, **kwargs)
         kw_face['linewidth'] = 0
         kw_edge['facecolor'] = 'none'
-        if _version_cartopy >= 0.18:
+        if dependencies._version_cartopy >= 0.18:
             self.patch.update(kw_face)
             self.spines['geo'].update(kw_edge)
         else:
@@ -1017,7 +1014,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         # Gridline label toggling
         # Issue warning instead of error!
         if (
-            _version_cartopy < 0.18
+            dependencies._version_cartopy < 0.18
             and not isinstance(self.projection, (ccrs.Mercator, ccrs.PlateCarree))
         ):
             if any(latarray):
@@ -1067,7 +1064,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
             self.autoscale_view()
 
         # Adjust location
-        if _version_cartopy >= 0.18:
+        if dependencies._version_cartopy >= 0.18:
             self.patch._adjust_location()  # this does the below steps
         elif (
             getattr(self.background_patch, 'reclip', None)
@@ -1080,13 +1077,13 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
         # Apply aspect
         self.apply_aspect()
         for gl in self._gridliners:
-            if _version_cartopy >= 0.18:
+            if dependencies._version_cartopy >= 0.18:
                 gl._draw_gridliner(renderer=renderer)
             else:
                 gl._draw_gridliner(background_patch=self.background_patch)
 
         # Remove gridliners
-        if _version_cartopy < 0.18:
+        if dependencies._version_cartopy < 0.18:
             self._gridliners = []
 
         return super().get_tightbbox(renderer, *args, **kwargs)
@@ -1109,7 +1106,7 @@ class _CartopyAxes(GeoAxes, _GeoAxes):
             with rc.context(mode=2):  # do not reset gridline properties!
                 self._update_gridlines(self._gridlines_major, which='major')
                 self._update_gridlines(self._gridlines_minor, which='minor')
-            if _version_cartopy < 0.18:
+            if dependencies._version_cartopy < 0.18:
                 clipped_path = self.outline_patch.orig_path.clip_to_bbox(self.viewLim)
                 self.outline_patch._path = clipped_path
                 self.background_patch._path = clipped_path
@@ -1126,8 +1123,7 @@ class _BasemapAxes(GeoAxes):
     """
     Axes subclass for plotting basemap projections.
     """
-    #: The registered projection name.
-    name = 'proplot_basemap'
+    _name = 'basemap'
     _proj_class = Basemap
     _proj_north = ('npaeqd', 'nplaea', 'npstere')
     _proj_south = ('spaeqd', 'splaea', 'spstere')
@@ -1154,7 +1150,9 @@ class _BasemapAxes(GeoAxes):
         # and python immmediately crashes. Do not try again.
         import mpl_toolkits.basemap  # noqa: F401 verify package is available
         if not isinstance(map_projection, mbasemap.Basemap):
-            raise ValueError('BasemapAxes requires map_projection=mpl_toolkits.basemap.Basemap.')  # noqa: E501
+            raise ValueError(
+                'Basemap axes require map_projection=mpl_toolkits.basemap.Basemap.'
+            )
         map_projection = self._map_projection = copy.copy(map_projection)
         lon0 = self._get_lon0()
         if map_projection.projection in self._proj_polar:
