@@ -28,7 +28,7 @@ import numpy as np
 from matplotlib import RcParams
 
 from .internals import ic  # noqa: F401
-from .internals import _not_none, _snippet_manager, benchmarks, rcsetup, warnings
+from .internals import _not_none, docstring, rcsetup, warnings
 
 try:
     from IPython import get_ipython
@@ -92,7 +92,7 @@ default : bool, optional
     Whether to reload built-in default ProPlot settings.
     Default is ``True``.
 """
-_snippet_manager['rc.params'] = _rc_docstring
+docstring._snippet_manager['rc.params'] = _rc_docstring
 
 # Registration docstrings
 _shared_docstring = """
@@ -146,16 +146,16 @@ default : bool, optional
     Whether to reload the default {objects} packaged with ProPlot.
     Default is always ``False``.
 """
-_snippet_manager['rc.cmap_params'] = _register_docstring.format(objects='colormaps')
-_snippet_manager['rc.cycle_params'] = _register_docstring.format(objects='color cycles')  # noqa: E501
-_snippet_manager['rc.color_params'] = _register_docstring.format(objects='colors')
-_snippet_manager['rc.font_params'] = _register_docstring.format(objects='fonts')
-_snippet_manager['rc.cmap_args'] = _shared_docstring.format(objects='colormaps', type='Continuous')  # noqa: E501
-_snippet_manager['rc.cycle_args'] = _shared_docstring.format(objects='color cycles', type='Discrete')  # noqa: E501
-_snippet_manager['rc.color_args'] = _color_docstring
-_snippet_manager['rc.font_args'] = _font_docstring
-_snippet_manager['rc.cmap_exts'] = _cmap_exts_docstring
-_snippet_manager['rc.cycle_exts'] = _cycle_exts_docstring
+docstring._snippet_manager['rc.cmap_params'] = _register_docstring.format(objects='colormaps')  # noqa: E501
+docstring._snippet_manager['rc.cycle_params'] = _register_docstring.format(objects='color cycles')  # noqa: E501
+docstring._snippet_manager['rc.color_params'] = _register_docstring.format(objects='colors')  # noqa: E501
+docstring._snippet_manager['rc.font_params'] = _register_docstring.format(objects='fonts')  # noqa: E501
+docstring._snippet_manager['rc.cmap_args'] = _shared_docstring.format(objects='colormaps', type='Continuous')  # noqa: E501
+docstring._snippet_manager['rc.cycle_args'] = _shared_docstring.format(objects='color cycles', type='Discrete')  # noqa: E501
+docstring._snippet_manager['rc.color_args'] = _color_docstring
+docstring._snippet_manager['rc.font_args'] = _font_docstring
+docstring._snippet_manager['rc.cmap_exts'] = _cmap_exts_docstring
+docstring._snippet_manager['rc.cycle_exts'] = _cycle_exts_docstring
 
 
 def _init_user_file():
@@ -295,9 +295,10 @@ def _get_style_dicts(style, infer=False, filter=True):
                     kw = mpl.rc_params_from_file(style, use_default_template=False)
                 except IOError:
                     raise IOError(
-                        f'Style {style!r} not found in the style library and input is '
-                        'not a valid URL or path. Available styles are: '
-                        + ', '.join(map(repr, mstyle.available)) + '.'
+                        f'Style {style!r} not found in the style library and input '
+                        'is not a valid URL or file path. Available styles are: '
+                        + ', '.join(map(repr, mstyle.available))
+                        + '.'
                     )
         else:
             raise ValueError(f'Invalid style {style!r}. Must be string or dictionary.')
@@ -389,10 +390,11 @@ def _parse_format(rc_kw=None, rc_mode=None, **kwargs):
     return rc_kw, rc_mode, kw
 
 
-def _translate_loc(loc, mode, *, default=None):
+def _translate_loc(loc, mode, *, default=None, **kwargs):
     """
-    Translate the location string `loc` into a standardized form. The `mode` must be
-    a string for which there is a :rcraw:`mode.loc` setting.
+    Translate the location string `loc` into a standardized form. The `mode`
+    must be a string for which there is a :rcraw:`mode.loc` setting. Additional
+    options can be added with keyword arguments.
     """
     # Create specific options dictionary
     # NOTE: This is not inside validators.py because it is also used to
@@ -407,6 +409,8 @@ def _translate_loc(loc, mode, *, default=None):
         loc_dict = rcsetup.TEXT_LOCS
     else:
         raise ValueError(f'Invalid mode {mode!r}.')
+    loc_dict = loc_dict.copy()
+    loc_dict.update(kwargs)
 
     # Translate location
     if loc in (None, True):
@@ -417,7 +421,8 @@ def _translate_loc(loc, mode, *, default=None):
         except KeyError:
             raise KeyError(
                 f'Invalid {mode} location {loc!r}. Options are: '
-                + ', '.join(map(repr, loc_dict)) + '.'
+                + ', '.join(map(repr, loc_dict))
+                + '.'
             )
     elif (
         mode == 'legend'
@@ -505,7 +510,7 @@ def config_inline_backend(fmt=None):
 
     Parameters
     ----------
-    fmt : str or list of str, optional
+    fmt : str or sequence, optional
         The inline backend file format(s). Default is :rc:`inlinefmt`. Valid formats
         include ``'jpg'``, ``'png'``, ``'svg'``, ``'pdf'``, and ``'retina'``.
 
@@ -523,9 +528,7 @@ def config_inline_backend(fmt=None):
     elif np.iterable(fmt):
         fmt = list(fmt)
     else:
-        raise ValueError(
-            f'Invalid inline backend format {fmt!r}. Must be string or list thereof.'
-        )
+        raise ValueError(f'Invalid inline backend format {fmt!r}. Must be string.')
     ipython.magic('config InlineBackend.figure_formats = ' + repr(fmt))
     ipython.magic('config InlineBackend.rc = {}')
     ipython.magic('config InlineBackend.close_figures = True')
@@ -541,7 +544,7 @@ def use_style(style):
 
     Parameters
     ----------
-    style : str, dict, or list thereof
+    style : str or sequence or dict-like
         The matplotlib style name(s) or stylesheet filename(s), or dictionary(s)
         of settings. Use ``'default'`` to apply matplotlib default settings and
         ``'original'`` to include settings from your user ``matplotlibrc`` file.
@@ -560,7 +563,7 @@ def use_style(style):
     rc_proplot.update(kw_proplot)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def register_cmaps(*args, user=None, default=False):
     """
     Register named colormaps. This is called on import.
@@ -600,7 +603,7 @@ def register_cmaps(*args, user=None, default=False):
         pcolors._cmap_database[cmap.name] = cmap
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def register_cycles(*args, user=None, default=False):
     """
     Register named color cycles. This is called on import.
@@ -638,8 +641,8 @@ def register_cycles(*args, user=None, default=False):
         pcolors._cmap_database[cmap.name] = cmap
 
 
-@_snippet_manager
-def register_colors(*args, user=None, default=False, space='hcl', margin=0.1, **kwargs):
+@docstring._snippet_manager
+def register_colors(*args, user=None, default=False, space=None, margin=None, **kwargs):
     """
     Register named colors. This is called on import.
 
@@ -648,13 +651,15 @@ def register_colors(*args, user=None, default=False, space='hcl', margin=0.1, **
     %(rc.color_args)s
     %(rc.color_params)s
     space : {'hcl', 'hsl', 'hpl'}, optional
-        Ignored if `default` is ``False``. The colorspace used to select "perceptually
-        distinct" colors from the XKCD `color survey <https://xkcd.com/color/rgb/>`_.
+        The colorspace used to select "perceptually distinct" colors from the XKCD
+        `color survey <https://xkcd.com/color/rgb/>`__. Default is ``'hcl'``. If
+        passed then `default` is set to ``True``.
     margin : float, optional
-        Ignored if `default` is ``False``. The margin by which the normalized hue,
-        saturation, and luminance of each XKCD color must differ from the channel
-        values of the other XKCD colors to be deemed "perceptually distinct" and
-        registered. Must be between ``0`` and ``1``. ``0`` will register all colors.
+        The margin by which the normalized hue, saturation, and luminance of each
+        XKCD color must differ from the channel values of the other XKCD colors to
+        be deemed "perceptually distinct" and registered. Must fall between ``0``
+        and ``1`` (``0`` will register all colors). Default is ``0.1``. If
+        passed then `default` is set to ``True``.
     **kwargs
         Additional color name specifications passed as keyword arguments rather
         than positional dictionaries.
@@ -666,15 +671,14 @@ def register_colors(*args, user=None, default=False, space='hcl', margin=0.1, **
     register_fonts
     proplot.demos.show_colors
     """
-    # Default-only actions
+    # Add in base colors and CSS4 colors so user has no surprises
     from . import colors as pcolors
+    default = default or space is not None or margin is not None
+    margin = _not_none(margin, 0.1)
+    space = _not_none(space, 'hcl')
     if default:
-        # Reset native colors dictionary
-        pcolors._color_database.clear()  # clean out!
-        pcolors._color_database.cache.clear()  # clean out!
-
-        # Add in base colors and CSS4 colors so user has no surprises
-        for name, src in (('base', pcolors.COLORS_BASE), ('css', mcolors.CSS4_COLORS)):
+        pcolors._color_database.clear()  # MutableMapping ensures cache also clears
+        for src in (mcolors.CSS4_COLORS, pcolors.COLORS_BASE):
             pcolors._color_database.update(src)
 
     # Register input colors
@@ -693,31 +697,22 @@ def register_colors(*args, user=None, default=False, space='hcl', margin=0.1, **
 
     # Load colors from file and get their HCL values
     # NOTE: Colors that come *later* overwrite colors that come earlier.
+    srcs = {'opencolor': pcolors.COLORS_OPEN, 'xkcd': pcolors.COLORS_XKCD}
     for i, path in _iter_data_objects('colors', *paths, user=user, default=default):
-        # Read colors
-        loaded = pcolors._load_colors(path, ignore_base=(i == 0), warn_on_failure=True)
-
-        # Add user colors
-        cat, _ = os.path.splitext(os.path.basename(path))
-        if i != 0:
-            pcolors._color_database.update(loaded)
-
-        # Add open-color colors
-        elif cat == 'opencolor':
-            pcolors._color_database.update(loaded)
-            pcolors.COLORS_OPEN.update(loaded)
-
-        # Add xkcd colors after filtering
-        elif cat == 'xkcd':
-            loaded = pcolors._standardize_colors(loaded, space=space, margin=margin)
-            pcolors._color_database.update(loaded)
-            pcolors.COLORS_XKCD.update(loaded)
-
-        else:
-            raise RuntimeError(f'Unknown proplot color database {path!r}.')
+        loaded = pcolors._load_colors(path, warn_on_failure=True)
+        if i == 0:
+            cat, _ = os.path.splitext(os.path.basename(path))
+            if cat not in srcs:
+                raise RuntimeError(f'Unknown proplot color database {path!r}.')
+            src = srcs[cat]
+            if cat == 'xkcd':
+                loaded = pcolors._standardize_colors(loaded, space, margin)
+            loaded = {k: c for k, c in loaded.items() if k not in pcolors.COLORS_BASE}
+            src.update(loaded)  # needed for demos.show_colors()
+        pcolors._color_database.update(loaded)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def register_fonts(*args, user=True, default=False):
     """
     Register font names.
@@ -769,7 +764,10 @@ def register_fonts(*args, user=True, default=False):
     fnames_all = {font.fname for font in mfonts.fontManager.ttflist}
     fnames_proplot -= fnames_proplot_ttc
     if not fnames_all >= fnames_proplot:
-        warnings._warn_proplot('Rebuilding font cache.')
+        warnings._warn_proplot(
+            'Rebuilding font cache. This may increase import time. '
+            'Usually happens after importing proplot for the first time.'
+        )
         if hasattr(mfonts.fontManager, 'addfont'):
             # Newer API lets us add font files manually and deprecates TTFPATH. However
             # to cache fonts added this way, we must call json_dump explicitly.
@@ -801,7 +799,8 @@ def register_fonts(*args, user=True, default=False):
     # NOTE: 'Thin' filter is ugly kludge but without this matplotlib picks up on
     # Roboto thin ttf files installed on the RTD server when compiling docs.
     mfonts.fontManager.ttflist = [
-        font for font in mfonts.fontManager.ttflist
+        font
+        for font in mfonts.fontManager.ttflist
         if os.path.splitext(font.fname)[1] != '.ttc'
         or 'Thin' in os.path.basename(font.fname)
     ]
@@ -838,7 +837,7 @@ class Configurator(MutableMapping, dict):
     def __delattr__(self, attr):  # noqa: U100
         raise RuntimeError('rc settings cannot be deleted.')
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def __init__(self, local=True, user=True, default=True, **kwargs):
         """
         Parameters
@@ -1045,14 +1044,18 @@ class Configurator(MutableMapping, dict):
         # Fontsize
         # NOTE: Re-application of e.g. size='small' uses the updated 'font.size'
         elif contains('font.size'):
-            kw_proplot.update({
-                key: value for key, value in rc_proplot.items()
-                if key in rcsetup.FONT_KEYS and value in mfonts.font_scalings
-            })
-            kw_matplotlib.update({
-                key: value for key, value in rc_matplotlib.items()
-                if key in rcsetup.FONT_KEYS and value in mfonts.font_scalings
-            })
+            kw_proplot.update(
+                {
+                    key: value for key, value in rc_proplot.items()
+                    if key in rcsetup.FONT_KEYS and value in mfonts.font_scalings
+                }
+            )
+            kw_matplotlib.update(
+                {
+                    key: value for key, value in rc_matplotlib.items()
+                    if key in rcsetup.FONT_KEYS and value in mfonts.font_scalings
+                }
+            )
 
         # When linewidth is zero set tick lengths to zero to avoid unnecessary
         # padding of tick labels. TODO: Document this feature
@@ -1330,7 +1333,8 @@ class Configurator(MutableMapping, dict):
         if cat not in rcsetup._rc_categories:
             raise ValueError(
                 f'Invalid rc category {cat!r}. Valid categories are: '
-                + ', '.join(map(repr, rcsetup._rc_categories)) + '.'
+                + ', '.join(map(repr, rcsetup._rc_categories))
+                + '.'
             )
         for key in self:
             if not re.match(fr'\A{cat}\.[^.]+\Z', key):
@@ -1393,7 +1397,7 @@ class Configurator(MutableMapping, dict):
 
         Parameters
         ----------
-        *args : str, dict, or both, optional
+        *args : str or dict-like, optional
             A dictionary containing `rc` keys and values. You can also pass
             a "category" name as the first argument, in which case all
             settings are prepended with ``'category.'``. For example,
@@ -1428,7 +1432,7 @@ class Configurator(MutableMapping, dict):
         for key, value in kw.items():
             self.__setitem__(prefix + key, value)
 
-    @_snippet_manager
+    @docstring._snippet_manager
     def reset(self, local=True, user=True, default=True, **kwargs):
         """
         Reset the configurator to its initial state.
@@ -1471,13 +1475,19 @@ class Configurator(MutableMapping, dict):
                     try:
                         ikw_proplot, ikw_matplotlib = self._get_params(key, val)
                     except KeyError:
-                        warnings._warn_proplot(f'Invalid rc key {key!r} on {message}.', 'default')  # noqa: E501
+                        warnings._warn_proplot(
+                            f'Invalid rc key {key!r} on {message}.', 'default'
+                        )
                         continue
                     except ValueError as err:
-                        warnings._warn_proplot(f'Invalid rc val {val!r} for key {key!r} on {message}: {err}', 'default')  # noqa: E501
+                        warnings._warn_proplot(
+                            f'Invalid rc val {val!r} for key {key!r} on {message}: {err}', 'default'  # noqa: E501
+                        )
                         continue
                     except warnings.ProPlotWarning as err:
-                        warnings._warn_proplot(f'Outdated rc key {key!r} on {message}: {err}', 'default')  # noqa: E501
+                        warnings._warn_proplot(
+                            f'Outdated rc key {key!r} on {message}: {err}', 'default'
+                        )
                         warnings.simplefilter('ignore', warnings.ProPlotWarning)
                         ikw_proplot, ikw_matplotlib = self._get_params(key, val)
                 # Update the settings
@@ -1626,13 +1636,9 @@ rc_matplotlib = mpl.rcParams  # PEP8 4 lyfe
 #: validated and restricted to recognized setting names.
 rc_proplot = rcsetup._rc_proplot_default.copy()  # a validated rcParams-style dict
 
-# Initialize configurator
-with benchmarks._benchmark('rc'):
-    _ = Configurator(skip_cycle=True)
-
 #: Instance of `Configurator`. This controls both `rc_matplotlib` and `rc_proplot`
 #: settings. See the :ref:`configuration guide <ug_config>` for details.
-rc = _
+rc = Configurator(skip_cycle=True)
 
 # Deprecated
 RcConfigurator = warnings._rename_objs(
