@@ -13,7 +13,7 @@ from . import colors as pcolors
 from . import constructor, ui
 from .config import _get_data_folders, rc
 from .internals import ic  # noqa: F401
-from .internals import _not_none, _snippet_manager, warnings
+from .internals import _not_none, docstring, warnings
 from .utils import to_rgb, to_xyz
 
 __all__ = [
@@ -26,8 +26,8 @@ __all__ = [
 ]
 
 COLORS_TABLE = {
-    # NOTE: Just want the names but point to the dictionaries because they
-    # get filled after this module is imported in __init__.
+    # NOTE: Just want the names but point to the dictionaries because
+    # they don't get filled until after __init__ imports this module.
     'base': pcolors.COLORS_BASE,
     'opencolor': pcolors.COLORS_OPEN,
     'xkcd': pcolors.COLORS_XKCD,
@@ -168,23 +168,18 @@ CYCLES_TABLE = {
     ),
 }
 
-_snippet_manager['show.colorbars'] = """
-length : float or str, optional
-    The length of the colorbars. Units are interpreted by
-    `~proplot.utils.units`.
+_colorbar_docstring = """
+length : unit-spec, optional
+    The length of the colorbars.
+    %(units.in)s
 width : float or str, optional
-    The width of the colorbars. Units are interpreted by
-    `~proplot.utils.units`.
+    The width of the colorbars.
+    %(units.in)s
 """
-_snippet_manager['color.categories'] = ', '.join(
-    f'``{cat!r}``' for cat in COLORS_TABLE
-)
-_snippet_manager['cmap.categories'] = ', '.join(
-    f'``{cat!r}``' for cat in CMAPS_TABLE
-)
-_snippet_manager['cycle.categories'] = ', '.join(
-    f'``{cat!r}``' for cat in CYCLES_TABLE
-)
+docstring._snippet_manager['demos.colors'] = ', '.join(f'``{cat!r}``' for cat in COLORS_TABLE)  # noqa: E501
+docstring._snippet_manager['demos.cmaps'] = ', '.join(f'``{cat!r}``' for cat in CMAPS_TABLE)  # noqa: E501
+docstring._snippet_manager['demos.cycles'] = ', '.join(f'``{cat!r}``' for cat in CYCLES_TABLE)  # noqa: E501
+docstring._snippet_manager['demos.colorbar'] = _colorbar_docstring
 
 
 def show_channels(
@@ -221,8 +216,10 @@ def show_channels(
 
     Returns
     -------
-    `~proplot.figure.Figure`
+    proplot.figure.Figure
         The figure.
+    proplot.gridspec.SubplotGrid
+        The subplot grid.
 
     See also
     --------
@@ -340,8 +337,10 @@ def show_colorspaces(*, luminance=None, saturation=None, hue=None, refwidth=2):
 
     Returns
     -------
-    `~proplot.figure.Figure`
+    proplot.figure.Figure
         The figure.
+    proplot.gridspec.SubplotGrid
+        The subplot grid.
 
     See also
     --------
@@ -385,12 +384,12 @@ def show_colorspaces(*, luminance=None, saturation=None, hue=None, refwidth=2):
 
     # Make figure, with black indicating invalid values
     # Note we invert the x-y ordering for imshow
-    fig, axs = ui.subplots(ncols=3, refwidth=refwidth, share=False, innerpad=0.5)
+    fig, axs = ui.subplots(refwidth=refwidth, ncols=3, share=False, innerpad=0.5)
     for ax, space in zip(axs, ('hcl', 'hsl', 'hpl')):
         rgba = np.ones((*hsl.shape[:2][::-1], 4))  # RGBA
         for j in range(hsl.shape[0]):
             for k in range(hsl.shape[1]):
-                rgb_jk = to_rgb(hsl[j, k, :].flat, space)
+                rgb_jk = to_rgb(hsl[j, k, :], space)
                 if not all(0 <= c <= 1 for c in rgb_jk):
                     rgba[k, j, 3] = 0  # black cell
                 else:
@@ -479,8 +478,8 @@ def _draw_bars(
     # Allocate two colorbar widths for each title of sections
     naxs = 2 * len(cmapdict) + sum(map(len, cmapdict.values()))
     fig, axs = ui.subplots(
-        nrows=naxs, refwidth=length, refheight=width,
-        share=False, top='-1em', hspace='2pt',
+        refwidth=length, refheight=width,
+        nrows=naxs, share=False, hspace='2pt', top='-1em',
     )
     iax = -1
     nheads = nbars = 0  # for deciding which axes to plot in
@@ -513,7 +512,7 @@ def _draw_bars(
     return fig, axs
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def show_cmaps(*args, **kwargs):
     """
     Generate a table of the registered colormaps or the input colormaps
@@ -531,20 +530,23 @@ def show_cmaps(*args, **kwargs):
         Category name for colormaps that are unknown to ProPlot. The
         default is ``'User'``. Set this to ``False`` to hide
         unknown colormaps.
-    include : str or list of str, optional
-        Category names to be shown in the table. Use this to limit the table
-        to a subset of categories. Valid categories are %(cmap.categories)s.
-    ignore : str or list of str, optional
+    include : str or sequence of str, optional
+        Category names to be shown in the table. Use this to limit
+        the table to a subset of categories. Valid categories are
+        %(demos.cmaps)s.
+    ignore : str or sequence of str, optional
         Used only if `include` was not passed. Category names to be removed from the
         table. Default is ``'MATLAB'``, ``'GNUplot'``, ``'GIST'``, and ``'Other'``.
-        Use of these colormaps is discouraged, because they contain non-uniform color
+        Use of these colormaps is discouraged because they contain non-uniform color
         transitions (see the :ref:`user guide <ug_perceptual>`).
-    %(show.colorbars)s
+    %(demos.colorbar)s
 
     Returns
     -------
-    `~proplot.figure.Figure`
+    proplot.figure.Figure
         The figure.
+    proplot.gridspec.SubplotGrid
+        The subplot grid.
 
     See also
     --------
@@ -572,7 +574,7 @@ def show_cmaps(*args, **kwargs):
     return _draw_bars(cmaps, **kwargs)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def show_cycles(*args, **kwargs):
     """
     Generate a table of registered color cycles or the input color cycles
@@ -586,18 +588,21 @@ def show_cycles(*args, **kwargs):
     unknown : str, optional
         Category name for cycles that are unknown to ProPlot. The default
         is ``'User'``. Set this to ``False`` to hide unknown colormaps.
-    include : str or list of str, optional
-        Category names to be shown in the table. Use this to limit the table
-        to a subset of categories. Valid categories are %(cycle.categories)s.
-    ignore : str or list of str, optional
-        Used only if `include` was not passed. Category names to be removed from
-        the table. Default is ``'MATLAB'``, ``'GNUplot'``, ``'GIST'``, and ``'Other'``.
-    %(show.colorbars)s
+    include : str or sequence of str, optional
+        Category names to be shown in the table. Use this to limit
+        the table to a subset of categories. Valid categories are
+        %(demos.cycles)s.
+    ignore : str or sequence of str, optional
+        Used only if `include` was not passed. Category names to be removed
+        from the table.
+    %(demos.colorbar)s
 
     Returns
     -------
-    `~proplot.figure.Figure`
+    proplot.figure.Figure
         The figure.
+    proplot.gridspec.SubplotGrid
+        The subplot grid.
 
     See also
     --------
@@ -647,7 +652,7 @@ def _filter_colors(hcl, ihue, nhues, minsat):
     return not gray and color
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def show_colors(
     *, nhues=17, minsat=10, unknown='User', include=None, ignore=None
 ):
@@ -666,17 +671,20 @@ def show_colors(
     unknown : str, optional
         Category name for color names that are unknown to ProPlot. The default
         is ``'User'``. Set this to ``False`` to hide unknown color names.
-    include : str or list of str, optional
-        Category names to be shown in the table. Use this to limti the table
-        to a subset of categories. Valid categories are %(color.categories)s.
-    ignore : str or list of str, optional
+    include : str or sequence of str, optional
+        Category names to be shown in the table. Use this to limit
+        the table to a subset of categories. Valid categories are
+        %(demos.colors)s.
+    ignore : str or sequence of str, optional
         Used only if `include` was not passed. Category names to be removed
         from the colormap table. Default is ``'CSS4'``.
 
     Returns
     -------
-    fig : `~proplot.figure.Figure`
+    proplot.figure.Figure
         The figure.
+    proplot.gridspec.SubplotGrid
+        The subplot grid.
     """
     # Tables of known colors to be plotted
     colordict = {}
@@ -749,10 +757,10 @@ def show_colors(
     maxcols = max(names.shape[0] for names in namess.values())
     hratios = tuple(names.shape[1] for names in namess.values())
     fig, axs = ui.subplots(
-        nrows=len(include),
-        hratios=hratios,
         figwidth=figwidth,
         refaspect=refaspect,
+        nrows=len(include),
+        hratios=hratios,
     )
     title_dict = {
         'css4': 'CSS4 colors',
@@ -824,13 +832,20 @@ def show_fonts(
         Greek letters, Arabic numerals, and some simple mathematical symbols.
     size : float, optional
         The font size in points.
-    weight : weight-spec, optional
+    weight : str, optional
         The font weight.
-    style : style-spec, optional
+    style : str, optional
         The font style.
-    stretch : stretch-spec, optional
+    stretch : str, optional
         The font stretch.
 
+    Returns
+    -------
+    proplot.figure.Figure
+        The figure.
+    proplot.gridspec.SubplotGrid
+        The subplot grid.
+
     See also
     --------
     show_cmaps
@@ -840,11 +855,13 @@ def show_fonts(
     if not args and family is None:
         # User fonts and sans-serif fonts. Note all proplot sans-serif
         # fonts are added to 'font.sans-serif' by default
-        args = sorted({
-            font.name for font in mfonts.fontManager.ttflist
-            if font.name in rc['font.sans-serif']
-            or _get_data_folders('fonts')[1] == os.path.dirname(font.fname)
-        })
+        args = sorted(
+            {
+                font.name for font in mfonts.fontManager.ttflist
+                if font.name in rc['font.sans-serif']
+                or _get_data_folders('fonts')[1] == os.path.dirname(font.fname)
+            }
+        )
     elif family is not None:
         options = ('serif', 'sans-serif', 'monospace', 'cursive', 'fantasy', 'tex-gyre')
         if family not in options:
@@ -865,11 +882,12 @@ def show_fonts(
             )
         else:
             family_fonts = rc['font.' + family]
-        args = (
-            *args, *sorted({
+        args = list(args)
+        args += sorted(
+            {
                 font.name for font in mfonts.fontManager.ttflist
                 if font.name in family_fonts
-            })
+            }
         )
 
     # Text
@@ -887,9 +905,9 @@ def show_fonts(
         )
 
     # Create figure
+    refheight = 1.2 * (text.count('\n') + 2.5) * size / 72
     fig, axs = ui.subplots(
-        ncols=1, nrows=len(args), space=0,
-        refwidth=4.5, refheight=1.2 * (text.count('\n') + 2.5) * size / 72,
+        refwidth=4.5, refheight=refheight, nrows=len(args), ncols=1, space=0,
         mathtext_fallback=False
     )
     axs.format(
