@@ -1,36 +1,27 @@
 #!/usr/bin/env python3
 """
-Utilities used internally by proplot.
+Internal utilities.
 """
 import inspect
 
 import numpy as np
 
-from . import benchmarks, dependencies, docstring, rcsetup, warnings  # noqa: F401
-from .dependencies import _version, _version_cartopy, _version_mpl  # noqa: F401
-from .docstring import _snippet_manager  # noqa: F401
+from . import (  # noqa: F401
+    benchmarks, context, data, dependencies, docstring, rcsetup, text, warnings
+)
 
 try:  # print debugging
     from icecream import ic
 except ImportError:  # graceful fallback if IceCream isn't installed
     ic = lambda *args: print(*args)  # noqa: E731
 
-INTERNAL_PARAMS = {  # silently pop these if we don't reach certain internal utilities
-    'to_centers',
-    'line_plot',
-    'contour_plot',
-    'default_cmap',
-    'default_discrete',
-    'skip_autolev',
-}
 
-# Alias dictionaries. This package only works with a subset of available artists
-# and keywords so we simply create our own system rather than working with
-# matplotlib's normalize_kwargs and _alias_maps.
+# Keyword aliases. We only work with a small subset of artists so we create our
+# own system rather than using matplotlib's normalize_kwargs and _alias_maps.
 # WARNING: Add pseudo-props 'edgewidth' and 'fillcolor' for patch edges and faces
 # WARNING: Critical that alias does not appear in key dict or else _translate_kwargs
 # will overwrite settings with None after popping them!
-_alias_dicts = {
+ALIAS_MAPS = {
     'rgba': {
         'red': ('r',),
         'green': ('g',),
@@ -43,40 +34,46 @@ _alias_dicts = {
         'luminance': ('l',),
         'alpha': ('a',),
     },
-    'line': {  # copied from lines.py but expanded to include plurals
-        'antialiased': ('aa',),
-        'alpha': ('a', 'alphas'),
-        'color': ('c', 'colors'),
-        'linewidth': ('lw', 'linewidths'),
-        'linestyle': ('ls', 'linestyles'),
-        'drawstyle': ('ds', 'drawstyles'),
-        'dashes': ('d',),
-        'marker': ('m', 'markers'),
-        'markersize': ('s', 'ms', 'markersizes'),
-        'markeredgecolor': ('mec', 'markeredgecolors'),
-        'markeredgewidth': ('mew', 'markeredgewidths'),
-        'markerfacecolor': ('mfc', 'markerfacecolors', 'mc', 'markercolor', 'markercolors'),  # noqa: E501
-        'fillstyle': ('fs', 'fillstyles', 'mfs', 'markerfillstyle', 'markerfillstyles'),
-        'zorder': ('z', 'zorders'),
-    },
-    'collection': {  # NOTE: face color is ignored for line collections
-        'alphas': ('a', 'alpha'),
-        'colors': ('c', 'color'),
-        'edgecolors': ('ec', 'edgecolor'),
-        'facecolors': ('fc', 'fillcolor', 'fillcolors'),
-        'linewidths': ('lw', 'linewidth', 'ew', 'edgewidth', 'edgewidths'),
-        'linestyles': ('ls', 'linestyle'),
-        'zorder': ('z', 'zorders'),
-    },
     'patch': {
-        'alpha': ('a', 'alphas', 'facealpha', 'facealphas', 'fillalpha', 'fillalphas'),
+        'alpha': ('a', 'alphas', 'fa', 'facealpha', 'facealphas', 'fillalpha', 'fillalphas'),  # noqa: E501
         'color': ('c', 'colors'),
         'edgecolor': ('ec', 'edgecolors'),
         'facecolor': ('fc', 'facecolors', 'fillcolor', 'fillcolors'),
-        'linewidth': ('lw', 'linewidths', 'ew', 'edgewidth', 'edgewidths'),
-        'linestyle': ('ls', 'linestyles'),
-        'zorder': ('z', 'zorders'),
         'hatch': ('h', 'hatching'),
+        'linestyle': ('ls', 'linestyles'),
+        'linewidth': ('lw', 'linewidths', 'ew', 'edgewidth', 'edgewidths'),
+        'zorder': ('z', 'zorders'),
+    },
+    'collection': {  # NOTE: face color is ignored for line collections
+        'alpha': ('a', 'alphas'),  # WARNING: collections and contours use singular!
+        'colors': ('c', 'color'),
+        'edgecolors': ('ec', 'edgecolor', 'mec', 'markeredgecolor', 'markeredgecolors'),
+        'facecolors': (
+            'fc', 'facecolor', 'fillcolor', 'fillcolors',
+            'mc', 'markercolor', 'markercolors', 'mfc', 'markerfacecolor', 'markerfacecolors'  # noqa: E501
+        ),
+        'linestyles': ('ls', 'linestyle'),
+        'linewidths': ('lw', 'linewidth', 'ew', 'edgewidth', 'edgewidths', 'mew', 'markeredgewidth', 'markeredgewidths'),  # noqa: E501
+        'sizes': ('s', 'ms', 'markersize', 'markersizes'),
+        'zorder': ('z', 'zorders'),
+    },
+    'line': {  # copied from lines.py but expanded to include plurals
+        'alpha': ('a', 'alphas'),
+        'color': ('c', 'colors'),
+        'dashes': ('d', 'dash'),
+        'drawstyle': ('ds', 'drawstyles'),
+        'fillstyle': ('fs', 'fillstyles', 'mfs', 'markerfillstyle', 'markerfillstyles'),
+        'linestyle': ('ls', 'linestyles'),
+        'linewidth': ('lw', 'linewidths'),
+        'marker': ('m', 'markers'),
+        'markersize': ('s', 'ms', 'markersizes', 'sizes'),
+        'markeredgewidth': ('ew', 'edgewidth', 'edgewidths', 'mew', 'markeredgewidths'),
+        'markeredgecolor': ('ec', 'edgecolor', 'edgecolors', 'mec', 'markeredgecolors'),
+        'markerfacecolor': (
+            'fc', 'facecolor', 'facecolors', 'fillcolor', 'fillcolors',
+            'mc', 'markercolor', 'markercolors', 'mfc', 'markerfacecolors'
+        ),
+        'zorder': ('z', 'zorders'),
     },
     'text': {
         'text': (),
@@ -143,6 +140,42 @@ def _keyword_to_positional(options, *args, allow_extra=False, **kwargs):
     return args, kwargs
 
 
+def _pop_params(kwargs, *funcs, ignore_internal=False):
+    """
+    Pop parameters of the input functions or methods.
+    """
+    internal_params = {
+        'default_cmap',
+        'default_discrete',
+        'inbounds',
+        'plot_contours',
+        'plot_lines',
+        'skip_autolev',
+        'to_centers',
+    }
+    output = {}
+    for func in funcs:
+        sig = inspect.signature(func)
+        for key in sig.parameters:
+            value = kwargs.pop(key, None)
+            if ignore_internal and key in internal_params:
+                continue
+            if value is not None:
+                output[key] = value
+    return output
+
+
+def _get_aliases(category, *keys):
+    """
+    Get all available aliases.
+    """
+    aliases = []
+    for key in keys:
+        aliases.append(key)
+        aliases.extend(ALIAS_MAPS[category][key])
+    return tuple(aliases)
+
+
 def _translate_kwargs(input, output, *keys, **aliases):
     """
     The driver function.
@@ -164,9 +197,7 @@ def _translate_props(input, output, *categories, prefix=None, ignore=None):  # n
     # Get properties
     prefix = prefix or ''  # e.g. 'box' for boxlw, boxlinewidth, etc.
     for category in categories:
-        if category not in _alias_dicts:
-            raise ValueError(f'Invalid alias category {category!r}.')
-        for key, aliases in _alias_dicts[category].items():
+        for key, aliases in ALIAS_MAPS[category].items():
             if isinstance(aliases, str):
                 aliases = (aliases,)
             opts = {prefix + alias: input.pop(prefix + alias, None) for alias in (key, *aliases)}  # noqa: E501
@@ -213,20 +244,28 @@ def _process_props(src, *categories, **kwargs):
     return _translate_props(src, src, *categories, **kwargs)
 
 
-def _pop_params(kwargs, *funcs, ignore_internal=False):
+def _iter_children(*args):
     """
-    Pop parameters of the input functions or methods.
+    Iterate through `_children` of `HPacker`, `VPacker`, and `DrawingArea`.
+    This is used to update legend handle properties.
     """
-    output = {}
-    for func in funcs:
-        sig = inspect.signature(func)
-        for key in sig.parameters:
-            value = kwargs.pop(key, None)
-            if ignore_internal and key in INTERNAL_PARAMS:
-                continue
-            if value is not None:
-                output[key] = value
-    return output
+    for arg in args:
+        if hasattr(arg, '_children'):
+            yield from _iter_children(*arg._children)
+        elif arg is not None:
+            yield arg
+
+
+def _iter_iterables(*args):
+    """
+    Iterate over arbitrary nested lists of iterables. Used for deciphering legend input.
+    Things can get complicated with e.g. bar colunns plus negative-positive colors.
+    """
+    for arg in args:
+        if np.iterable(arg):
+            yield from _iter_iterables(*arg)
+        elif arg is not None:
+            yield arg
 
 
 def _fill_guide_kw(kwargs, **pairs):
@@ -246,14 +285,6 @@ def _fill_guide_kw(kwargs, **pairs):
             kwargs[key] = value
 
 
-def _guide_kw_to_arg(name, kwargs, **pairs):
-    """
-    Add to the `colorbar_kw` or `legend_kw` dict if there are no conflicts.
-    """
-    kw = kwargs.setdefault(f'{name}_kw', {})
-    _fill_guide_kw(kw, **pairs)
-
-
 def _guide_kw_from_obj(obj, name, kwargs):
     """
     Add to the dict from settings stored on the object if there are no conflicts.
@@ -280,38 +311,9 @@ def _guide_kw_to_obj(obj, name, kwargs):
             _guide_kw_to_obj(iobj, name, kwargs)
 
 
-class _empty_context(object):
+def _guide_kw_to_arg(name, kwargs, **pairs):
     """
-    A dummy context manager.
+    Add to the `colorbar_kw` or `legend_kw` dict if there are no conflicts.
     """
-    def __init__(self):
-        pass
-
-    def __enter__(self):
-        pass
-
-    def __exit__(self, *args):  # noqa: U100
-        pass
-
-
-class _state_context(object):
-    """
-    Temporarily modify attribute(s) for an arbitrary object.
-    """
-    def __init__(self, obj, **kwargs):
-        self._obj = obj
-        self._attrs_new = kwargs
-        self._attrs_prev = {
-            key: getattr(obj, key) for key in kwargs if hasattr(obj, key)
-        }
-
-    def __enter__(self):
-        for key, value in self._attrs_new.items():
-            setattr(self._obj, key, value)
-
-    def __exit__(self, *args):  # noqa: U100
-        for key in self._attrs_new.keys():
-            if key in self._attrs_prev:
-                setattr(self._obj, key, self._attrs_prev[key])
-            else:
-                delattr(self._obj, key)
+    kw = kwargs.setdefault(f'{name}_kw', {})
+    _fill_guide_kw(kw, **pairs)
