@@ -15,7 +15,7 @@ from matplotlib import rcParams as rc_matplotlib
 
 from .externals import hsluv
 from .internals import ic  # noqa: F401
-from .internals import _not_none, _snippet_manager, warnings
+from .internals import _not_none, docstring, warnings
 
 __all__ = [
     'arange',
@@ -52,7 +52,7 @@ UNIT_DICT = {
     'mm': 0.03937,
     'pc': 1 / 6.0,
     'pt': 1 / 72.0,
-    'ly': 3.725e+17,
+    'ly': 3.725e17,
 }
 
 
@@ -60,44 +60,53 @@ UNIT_DICT = {
 # NOTE: Try to fit this into a single line. Cannot break up with newline as that will
 # mess up docstring indentation since this is placed in indented param lines.
 _units_docstring = 'If float, units are {units}. If string, interpreted by `~proplot.utils.units`.'  # noqa: E501
-_snippet_manager['units.pt'] = _units_docstring.format(units='points')
-_snippet_manager['units.in'] = _units_docstring.format(units='inches')
-_snippet_manager['units.em'] = _units_docstring.format(units='em-widths')
+docstring._snippet_manager['units.pt'] = _units_docstring.format(units='points')
+docstring._snippet_manager['units.in'] = _units_docstring.format(units='inches')
+docstring._snippet_manager['units.em'] = _units_docstring.format(units='em-widths')
 
 
 # Color docstrings
-_snippet_manager['param.rgba'] = """
+_docstring_rgba = """
 color : color-spec
     The color. Sanitized with `to_rgba`.
 """
-_snippet_manager['param.to_rgb'] = """
-color : str, 3-tuple, or 4-tuple
-    The color specification. Can be a tuple of channel values, a hex string,
-    a registered color name, a cycle color like ``'C0'``, or a colormap color
-    (see `~proplot.colors.ColorDatabase`).
+_docstring_to_rgb = """
+color : color-spec
+    The color. Can be a 3-tuple or 4-tuple of channel values, a hex
+    string, a registered color name, a cycle color like ``'C0'``, or
+    a 2-tuple colormap coordinate specification like ``('magma', 0.5)``
+    (see `~proplot.colors.ColorDatabase` for details).
 
-    If `space` is ``'rgb'``, this is a tuple of RGB values, and if any
-    channels are larger than ``2``, the channels are assumed to be on
-    the ``0`` to ``255`` scale and are divided by ``255``.
+    If `space` is ``'rgb'``, this is a tuple of RGB values, and any
+    channels are larger than ``2``, the channels are assumed to be
+    on the ``0`` to ``255`` scale and are divided by ``255``.
 space : {'rgb', 'hsv', 'hcl', 'hpl', 'hsl'}, optional
     The colorspace for the input channel values. Ignored unless `color` is
     a tuple of numbers.
-cycle : str or list, optional
+cycle : str, optional
     The registered color cycle name used to interpret colors that
     look like ``'C0'``, ``'C1'``, etc. Default is :rc:`cycle`.
+clip : bool, optional
+    Whether to clip channel values into the valid ``0`` to ``1`` range.
+    Default is ``True``.
 """
-_snippet_manager['param.space'] = """
+_docstring_space = """
 space : {'hcl', 'hpl', 'hsl', 'hsv'}, optional
     The hue-saturation-luminance-like colorspace used to transform the color.
     Default is the perceptually uniform colorspace ``'hcl'``.
 """
-_snippet_manager['return.hex'] = """
+_docstring_hex = """
 color : str
-    A HEX string.
+    An 8-digit HEX string indicating the
+    red, green, blue, and alpha channel values.
 """
+docstring._snippet_manager['utils.color'] = _docstring_rgba
+docstring._snippet_manager['utils.hex'] = _docstring_hex
+docstring._snippet_manager['utils.space'] = _docstring_space
+docstring._snippet_manager['utils.to'] = _docstring_to_rgb
 
 
-def _preserve_units(func):
+def _keep_units(func):
     """
     Very simple decorator to strip and re-apply the same units.
     """
@@ -115,15 +124,33 @@ def _preserve_units(func):
 
 def arange(min_, *args):
     """
-    Identical to `numpy.arange` but with inclusive endpoints. For
-    example, ``pplt.arange(2, 4)`` returns ``np.array([2, 3, 4])`` instead
-    of ``np.array([2, 3])``. This command is useful for generating lists of
-    tick locations or colorbar level boundaries.
+    Identical to `numpy.arange` but with inclusive endpoints. For example,
+    ``pplt.arange(2, 4)`` returns the numpy array ``[2, 3, 4]`` instead of
+    ``[2, 3]``. This is useful for generating lists of tick locations or
+    colormap levels, e.g. ``ax.format(xlocator=pplt.arange(0, 10))``
+    or ``ax.pcolor(levels=pplt.arange(0, 10))``.
+
+    Parameters
+    ----------
+    *args : float
+        If three arguments are passed, these are the minimum, maximum, and step
+        size. If fewer than three arguments are passed, the step size is ``1``.
+        If one argument is passed, this is the maximum, and the minimum is ``0``.
+
+    Returns
+    -------
+    numpy.ndarray
+        Array of points.
 
     See also
     --------
-    proplot.axes.CartesianAxes.format
+    numpy.arange
     proplot.constructor.Locator
+    proplot.axes.CartesianAxes.format
+    proplot.axes.PolarAxes.format
+    proplot.axes.GeoAxes.format
+    proplot.axes.Axes.colorbar
+    proplot.axes.PlotAxes
     """
     # Optional arguments just like np.arange
     if len(args) == 0:
@@ -151,26 +178,24 @@ def arange(min_, *args):
     return np.arange(min_, max_, step)
 
 
-@_preserve_units
+@_keep_units
 def edges(z, axis=-1):
     """
-    Calculate the approximate "edge" values along an axis given "center" values.
-    This is used internally to calculate graticule edges when you supply centers
-    to `~matplotlib.axes.Axes.pcolor` or `~matplotlib.axes.Axes.pcolormesh`. It
-    is also used to calculate colormap level boundaries when you supply centers
-    to plotting methods wrapped by `~proplot.axes.apply_cmap`.
+    Calculate the approximate "edge" values along an axis given "center" values. The
+    size of the axis is increased by one. This is used internally to calculate graticule
+    edges when you supply centers to pseudocolor commands.
 
     Parameters
     ----------
     z : array-like
-        Array of any shape or size.
+        An array of any shape.
     axis : int, optional
-        The axis along which "edges" are calculated. The size of this axis
-        will be increased by one.
+        The axis along which "edges" are calculated. The size of this
+        axis will be increased by one.
 
     Returns
     -------
-    `~numpy.ndarray`
+    numpy.ndarray
         Array of "edge" coordinates.
 
     See also
@@ -178,6 +203,7 @@ def edges(z, axis=-1):
     edges2d
     proplot.axes.PlotAxes.pcolor
     proplot.axes.PlotAxes.pcolormesh
+    proplot.axes.PlotAxes.pcolorfast
     """
     z = np.asarray(z)
     z = np.swapaxes(z, axis, -1)
@@ -187,29 +213,29 @@ def edges(z, axis=-1):
     # Inner edges
     zb[..., 1:-1] = 0.5 * (z[..., :-1] + z[..., 1:])
 
-    # Left, right edges
+    # Outer edges
     zb[..., 0] = 1.5 * z[..., 0] - 0.5 * z[..., 1]
     zb[..., -1] = 1.5 * z[..., -1] - 0.5 * z[..., -2]
 
     return np.swapaxes(zb, axis, -1)
 
 
-@_preserve_units
+@_keep_units
 def edges2d(z):
     """
-    Calculate the approximate "edge" values given a 2d grid of "center"
-    values. The size of both axes are increased by one. This is used
-    internally to calculate graticule edges when you supply centers to
-    `~matplotlib.axes.Axes.pcolor` or `~matplotlib.axes.Axes.pcolormesh`.
+    Calculate the approximate "edge" values given a 2D grid of "center"
+    values. The size of both axes is increased by one. This is used
+    internally to calculate graticule edges when you supply centers
+    to pseudocolor plot commands.
 
     Parameters
     ----------
     z : array-like
-        A 2d array.
+        A 2D array.
 
     Returns
     -------
-    `~numpy.ndarray`
+    numpy.ndarray
         Array of "edge" coordinates.
 
     See also
@@ -217,19 +243,18 @@ def edges2d(z):
     edges
     proplot.axes.PlotAxes.pcolor
     proplot.axes.PlotAxes.pcolormesh
+    proplot.axes.PlotAxes.pcolorfast
     """
     z = np.asarray(z)
     if z.ndim != 2:
-        raise ValueError(f'Input must be a 2d array, but got {z.ndim}d.')
+        raise ValueError(f'Input must be a 2D array, but got {z.ndim}D.')
     ny, nx = z.shape
     zb = np.zeros((ny + 1, nx + 1))
 
     # Inner edges
-    zb[1:-1, 1:-1] = 0.25 * (
-        z[1:, 1:] + z[:-1, 1:] + z[1:, :-1] + z[:-1, :-1]
-    )
+    zb[1:-1, 1:-1] = 0.25 * (z[1:, 1:] + z[:-1, 1:] + z[1:, :-1] + z[:-1, :-1])
 
-    # Left, right, top, bottom edges
+    # Outer edges
     zb[0, :] += edges(1.5 * z[0, :] - 0.5 * z[1, :])
     zb[-1, :] += edges(1.5 * z[-1, :] - 0.5 * z[-2, :])
     zb[:, 0] += edges(1.5 * z[:, 0] - 0.5 * z[:, 1])
@@ -271,28 +296,26 @@ def _transform_color(func, color, space):
     Standardize input for color transformation functions.
     """
     *color, opacity = to_rgba(color)
-    channels = list(to_xyz(color, space=space))
-    channels = func(channels)  # apply transform
-    color = to_rgb(channels, space=space)
-    color = tuple(np.clip(color, 0, 1))  # clip to valid range
-    return mcolors.to_hex((*color, opacity))
+    color = to_xyz(color, space=space)
+    color = func(list(color))  # apply transform
+    return to_hex((*color, opacity), space=space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def shift_hue(color, shift=0, space='hcl'):
     """
     Shift the hue channel of a color.
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     shift : float, optoinal
         The HCL hue channel is offset by this value.
-    %(param.space)s
+    %(utils.space)s
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -311,21 +334,21 @@ def shift_hue(color, shift=0, space='hcl'):
     return _transform_color(func, color, space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def scale_saturation(color, scale=1, space='hcl'):
     """
     Scale the saturation channel of a color.
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     scale : float, optoinal
         The HCL saturation channel is multiplied by this value.
-    %(param.space)s
+    %(utils.space)s
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -343,21 +366,21 @@ def scale_saturation(color, scale=1, space='hcl'):
     return _transform_color(func, color, space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def scale_luminance(color, scale=1, space='hcl'):
     """
     Scale the luminance channel of a color.
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     scale : float, optoinal
         The luminance channel is multiplied by this value.
-    %(param.space)s
+    %(utils.space)s
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -375,7 +398,7 @@ def scale_luminance(color, scale=1, space='hcl'):
     return _transform_color(func, color, space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def set_hue(color, hue, space='hcl'):
     """
     Return a color with a different hue and the same luminance and saturation
@@ -383,14 +406,14 @@ def set_hue(color, hue, space='hcl'):
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     hue : float, optional
         The new hue. Should lie between ``0`` and ``360`` degrees.
-    %(param.space)s
+    %(utils.space)s
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -408,7 +431,7 @@ def set_hue(color, hue, space='hcl'):
     return _transform_color(func, color, space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def set_saturation(color, saturation, space='hcl'):
     """
     Return a color with a different saturation and the same hue and luminance
@@ -416,14 +439,14 @@ def set_saturation(color, saturation, space='hcl'):
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     saturation : float, optional
         The new saturation. Should lie between ``0`` and ``360`` degrees.
-    %(param.space)s
+    %(utils.space)s
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -441,7 +464,7 @@ def set_saturation(color, saturation, space='hcl'):
     return _transform_color(func, color, space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def set_luminance(color, luminance, space='hcl'):
     """
     Return a color with a different luminance and the same hue and saturation
@@ -449,14 +472,14 @@ def set_luminance(color, luminance, space='hcl'):
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     luminance : float, optional
         The new luminance. Should lie between ``0`` and ``100``.
-    %(param.space)s
+    %(utils.space)s
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -474,20 +497,20 @@ def set_luminance(color, luminance, space='hcl'):
     return _transform_color(func, color, space)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def set_alpha(color, alpha):
     """
     Return a color with the opacity channel set to the specified value.
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     alpha : float, optional
         The new opacity. Should be between ``0`` and ``1``.
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -513,12 +536,14 @@ def _translate_cycle_color(color, cycle=None):
             cycle = _cmap_database[cycle].colors
         except (KeyError, AttributeError):
             cycles = sorted(
-                name for name, cmap in _cmap_database.items()
+                name
+                for name, cmap in _cmap_database.items()
                 if isinstance(cmap, mcolors.ListedColormap)
             )
             raise ValueError(
                 f'Invalid color cycle {cycle!r}. Options are: '
-                + ', '.join(map(repr, cycles)) + '.'
+                + ', '.join(map(repr, cycles))
+                + '.'
             )
     elif cycle is None:
         cycle = rc_matplotlib['axes.prop_cycle'].by_key()
@@ -532,22 +557,22 @@ def _translate_cycle_color(color, cycle=None):
     return cycle[int(color[-1]) % len(cycle)]
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def to_hex(color, space='rgb', cycle=None, keep_alpha=True):
     """
-    Translate the color in *any* format and from *any* colorspace
-    to a HEX string. This is a generalization of `matplotlib.colors.to_hex`.
+    Translate the color from an arbitrary colorspace to a HEX string.
+    This is a generalization of `matplotlib.colors.to_hex`.
 
     Parameters
     ----------
-    %(param.to_rgb)s
+    %(utils.to)s
     keep_alpha : bool, optional
         Whether to keep the opacity channel. If ``True`` an 8-digit HEX
         is returned. Otherwise a 6-digit HEX is returned. Default is ``True``.
 
     Returns
     -------
-    %(return.hex)s
+    %(utils.hex)s
 
     See also
     --------
@@ -560,16 +585,15 @@ def to_hex(color, space='rgb', cycle=None, keep_alpha=True):
     return mcolors.to_hex(rgba, keep_alpha=keep_alpha)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def to_rgb(color, space='rgb', cycle=None):
     """
-    Translate the color in *any* format and from *any* colorspace to an RGB
-    tuple. This is a generalization of `matplotlib.colors.to_rgb` and the
-    inverse of `to_xyz`.
+    Translate the color from an arbitrary colorspace to an RGB tuple. This is
+    a generalization of `matplotlib.colors.to_rgb` and the inverse of `to_xyz`.
 
     Parameters
     ----------
-    %(param.to_rgb)s
+    %(utils.to)s
 
     Returns
     -------
@@ -586,16 +610,15 @@ def to_rgb(color, space='rgb', cycle=None):
     return to_rgba(color, space=space, cycle=cycle)[:3]
 
 
-@_snippet_manager
-def to_rgba(color, space='rgb', cycle=None):
+@docstring._snippet_manager
+def to_rgba(color, space='rgb', cycle=None, clip=True):
     """
-    Translate the color in *any* format and from *any* colorspace to an RGB
-    tuple. This is a generalization of `matplotlib.colors.to_rgba` and the
-    inverse of `to_xyza`.
+    Translate the color from an arbitrary colorspace to an RGBA tuple. This is
+    a generalization of `matplotlib.colors.to_rgba` and the inverse of `to_xyz`.
 
     Parameters
     ----------
-    %(param.to_rgb)s
+    %(utils.to)s
 
     Returns
     -------
@@ -614,27 +637,28 @@ def to_rgba(color, space='rgb', cycle=None):
         color = _translate_cycle_color(color, cycle=cycle)
 
     # Translate RGB strings and (colormap, index) tuples
+    # NOTE: Cannot use is_color_like because might have HSL channel values
     opacity = 1
-    if isinstance(color, str) or np.iterable(color) and len(color) == 2:
-        try:
-            *color, opacity = mcolors.to_rgba(color)  # ensure is valid color
-        except (TypeError, ValueError):
-            raise ValueError(f'Invalid RGB argument {color!r}.')
-
-    # Pull out alpha channel
+    if (
+        isinstance(color, str)
+        or np.iterable(color) and len(color) == 2
+    ):
+        color = mcolors.to_rgba(color)  # also enforced validity
+    if (
+        not np.iterable(color)
+        or len(color) not in (3, 4)
+        or not all(isinstance(c, Real) for c in color)
+    ):
+        raise ValueError(f'Invalid color-spec {color!r}.')
     if len(color) == 4:
         *color, opacity = color
-    elif len(color) != 3:
-        raise ValueError(f'Invalid RGB argument {color!r}.')
 
     # Translate arbitrary colorspaces
     if space == 'rgb':
-        try:
-            if any(c > 2 for c in color):
-                color = [c / 255 for c in color]  # scale to within 0-1
-            color = tuple(color)
-        except (TypeError, ValueError):
-            raise ValueError(f'Invalid RGB argument {color!r}.')
+        if any(c > 2 for c in color):
+            color = tuple(c / 255 for c in color)  # scale to within 0-1
+        else:
+            pass
     elif space == 'hsv':
         color = hsluv.hsl_to_rgb(*color)
     elif space == 'hcl':
@@ -644,13 +668,18 @@ def to_rgba(color, space='rgb', cycle=None):
     elif space == 'hpl':
         color = hsluv.hpluv_to_rgb(*color)
     else:
-        raise ValueError(f'Invalid color {color!r} for colorspace {space!r}.')
+        raise ValueError(f'Invalid colorspace {space!r}.')
+
+    # Clip values. This should only be disabled when testing
+    # translation functions.
+    if clip:
+        color = np.clip(color, 0, 1)  # clip to valid range
 
     # Return RGB or RGBA
     return (*color, opacity)
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def to_xyz(color, space='hcl'):
     """
     Translate color in *any* format to a tuple of channel values in *any*
@@ -658,7 +687,7 @@ def to_xyz(color, space='hcl'):
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     space : {'hcl', 'hpl', 'hsl', 'hsv', 'rgb'}, optional
         The colorspace for the output channel values.
 
@@ -677,7 +706,7 @@ def to_xyz(color, space='hcl'):
     return to_xyza(color, space)[:3]
 
 
-@_snippet_manager
+@docstring._snippet_manager
 def to_xyza(color, space='hcl'):
     """
     Translate color in *any* format to a tuple of channel values in *any*
@@ -685,7 +714,7 @@ def to_xyza(color, space='hcl'):
 
     Parameters
     ----------
-    %(param.rgba)s
+    %(utils.color)s
     space : {'hcl', 'hpl', 'hsl', 'hsv', 'rgb'}, optional
         The colorspace for the output channel values.
 
@@ -734,7 +763,8 @@ def _fontsize_to_pt(size):
     except ValueError:
         raise KeyError(
             f'Invalid font size {size!r}. Can be points or one of the preset scalings: '
-            + ', '.join(f'{key!r} ({value})' for key, value in scalings.items()) + '.'
+            + ', '.join(f'{key!r} ({value})' for key, value in scalings.items())
+            + '.'
         )
 
 
@@ -743,18 +773,17 @@ def units(
     value, numeric=None, dest=None, *, fontsize=None, figure=None, axes=None, width=None
 ):
     """
-    Convert values and lists of values between arbitrary physical units. This
-    is used internally all over ProPlot, permitting flexible units for various
-    keyword arguments.
+    Convert values between arbitrary physical units. This is used internally all
+    over ProPlot, permitting flexible units for various keyword arguments.
 
     Parameters
     ----------
-    value : float or str or list thereof
-        A size specifier or *list thereof*. If numeric, units are converted from
-        `numeric` to `dest`. If string, units are converted to `dest` according
-        to the string specifier. The string should look like ``'123.456unit'``,
-        where the number is the magnitude and ``'unit'`` matches a key in
-        the below table.
+    value : float or str or sequence
+        A size specifier or sequence of size specifiers. If numeric, units are
+        converted from `numeric` to `dest`. If string, units are converted to
+        `dest` according to the string specifier. The string should look like
+        ``'123.456unit'``, where the number is the magnitude and ``'unit'``
+        matches a key in the below table.
 
         .. _units_table:
 
@@ -790,7 +819,7 @@ def units(
         The units associated with numeric input. Default is inches.
     dest : str, optional
         The destination units. Default is the same as `numeric`.
-    fontsize : size-spec, optional
+    fontsize : str or float, optional
         The font size in points used for scaling. Default is
         :rcraw:`font.size` for ``em`` and ``en`` units and
         :rcraw:`axes.titlesize` for ``Em`` and ``En`` units.
@@ -809,12 +838,14 @@ def units(
     fontsize_large = _not_none(fontsize, rc_matplotlib['axes.titlesize'])
     fontsize_large = _fontsize_to_pt(fontsize_large)
     unit_dict = UNIT_DICT.copy()
-    unit_dict.update({
-        'em': fontsize_small / 72.0,
-        'en': 0.5 * fontsize_small / 72.0,
-        'Em': fontsize_large / 72.0,
-        'En': 0.5 * fontsize_large / 72.0,
-    })
+    unit_dict.update(
+        {
+            'em': fontsize_small / 72.0,
+            'en': 0.5 * fontsize_small / 72.0,
+            'Em': fontsize_large / 72.0,
+            'En': 0.5 * fontsize_large / 72.0,
+        }
+    )
 
     # Scales for converting display units to inches
     # WARNING: In ipython shell these take the value 'figure'
@@ -851,7 +882,7 @@ def units(
     # Convert units for each value in list
     result = []
     singleton = not np.iterable(value) or isinstance(value, str)
-    for val in ((value,) if singleton else value):
+    for val in (value,) if singleton else value:
         # Silently pass None
         if val is None:
             result.append(val)
